@@ -18,7 +18,7 @@ package org.kie.workbench.common.forms.commons.shared.layout.impl;
 
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.forms.commons.shared.layout.FormLayoutTemplateGenerator;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 
 @RunWith(MockitoJUnitRunner.class)
 public class DynamicFormLayoutTemplateGeneratorTest extends FormLayoutTemplateGeneratorTest {
