@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *    http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -22,10 +22,12 @@ public interface DynamicDataBinderEditorView extends UberElement<DynamicDataBind
 
     interface Presenter {
 
-        void onBindingChange(String newBinding);
+        void onBindingChange();
     }
 
     void clear();
 
     void setFieldBinding(String fieldBinding);
+
+    String getFieldBinding();
 }
