@@ -22,7 +22,6 @@ import org.jboss.errai.common.client.api.annotations.MapsTo;
 import org.jboss.errai.common.client.api.annotations.Portable;
 import org.kie.workbench.common.forms.jbpm.model.authoring.AbstractJBPMFormModel;
 import org.kie.workbench.common.forms.jbpm.service.bpmn.util.BPMNVariableUtils;
-import org.kie.workbench.common.forms.model.FormModel;
 import org.kie.workbench.common.forms.model.ModelProperty;
 
 @Portable
@@ -37,8 +36,8 @@ public class TaskFormModel extends AbstractJBPMFormModel {
     public TaskFormModel(@MapsTo("processId") String processId,
                          @MapsTo("taskName") String taskName,
                          @MapsTo("properties") List<ModelProperty> properties) {
-        super(processId,
-              properties);
+        super(processId, properties);
+
         this.taskName = taskName;
     }
 
