@@ -24,6 +24,7 @@ import java.util.List;
 import java.util.Optional;
 import java.util.Set;
 import java.util.stream.Stream;
+
 import javax.enterprise.event.Event;
 
 import org.guvnor.common.services.project.backend.server.utils.PathUtil;
@@ -34,9 +35,12 @@ import org.guvnor.common.services.project.model.POM;
 import org.guvnor.common.services.project.model.WorkspaceProject;
 import org.guvnor.common.services.project.service.WorkspaceProjectService;
 import org.guvnor.common.services.shared.metadata.MetadataService;
+import org.guvnor.structure.backend.organizationalunit.config.SpaceConfigStorageRegistryImpl;
 import org.guvnor.structure.organizationalunit.OrganizationalUnit;
 import org.guvnor.structure.organizationalunit.OrganizationalUnitService;
 import org.guvnor.structure.organizationalunit.config.RepositoryInfo;
+import org.guvnor.structure.organizationalunit.config.SpaceConfigStorage;
+import org.guvnor.structure.organizationalunit.config.SpaceConfigStorageRegistry;
 import org.guvnor.structure.organizationalunit.impl.OrganizationalUnitImpl;
 import org.guvnor.structure.repositories.Branch;
 import org.guvnor.structure.repositories.EnvironmentParameters;
@@ -48,6 +52,7 @@ import org.guvnor.structure.server.repositories.RepositoryFactory;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
+import org.kie.workbench.common.screens.examples.exception.EmptyRemoteRepositoryException;
 import org.kie.workbench.common.screens.examples.model.Credentials;
 import org.kie.workbench.common.screens.examples.model.ExampleRepository;
 import org.kie.workbench.common.screens.examples.model.ImportProject;
@@ -55,23 +60,43 @@ import org.kie.workbench.common.screens.examples.validation.ImportProjectValidat
 import org.kie.workbench.common.screens.projecteditor.service.ProjectScreenService;
 import org.kie.workbench.common.services.shared.project.KieModule;
 import org.kie.workbench.common.services.shared.project.KieModuleService;
+import org.mockito.Answers;
 import org.mockito.ArgumentCaptor;
+import org.mockito.Captor;
 import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.Mockito;
+import org.mockito.junit.MockitoJUnitRunner;
 import org.uberfire.backend.vfs.Path;
 import org.uberfire.backend.vfs.PathFactory;
 import org.uberfire.io.IOService;
+import org.uberfire.java.nio.file.FileSystem;
 import org.uberfire.java.nio.file.spi.FileSystemProvider;
 import org.uberfire.java.nio.fs.jgit.JGitFileSystem;
 import org.uberfire.java.nio.fs.jgit.JGitPathImpl;
 import org.uberfire.spaces.Space;
 
 import static java.util.Collections.emptyList;
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertSame;
+import static org.junit.Assert.assertTrue;
 import static org.kie.workbench.common.screens.examples.backend.server.ImportUtils.makeGitRepository;
-import static org.mockito.Mockito.*;
+import static org.mockito.Mockito.any;
+import static org.mockito.Mockito.anyString;
+import static org.mockito.Mockito.doReturn;
+import static org.mockito.Mockito.eq;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.mockingDetails;
+import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.same;
+import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
-@RunWith(MockitoJUnitRunner.class)
+@RunWith(MockitoJUnitRunner.Silent.class)
 public class ProjectImportServiceImplTest {
 
     @Mock
@@ -111,6 +136,21 @@ public class ProjectImportServiceImplTest {
     @Mock
     private RepositoryService repoService;
 
+    @Mock
+    private SpaceConfigStorageRegistry spaceConfigStorageRegistry;
+
+    @Mock
+    private SpaceConfigStorage spaceConfigStorage;
+
+    @Mock
+    private OrganizationalUnit organizationalUnit;
+
+    @Mock
+    private Space space;
+
+    @Captor
+    private ArgumentCaptor<RepositoryEnvironmentConfigurations> configurations;
+
     @Before
     public void setup() {
         service = spy(new ProjectImportServiceImpl(ioService,
@@ -122,12 +162,26 @@ public class ProjectImportServiceImplTest {
                                                    projectService,
                                                    projectScreenService,
                                                    newProjectEvent,
-                                                   repoService));
+                                                   repoService,
+                                                   spaceConfigStorageRegistry));
+
+        when(spaceConfigStorageRegistry.get(anyString())).thenReturn(spaceConfigStorage);
+        when(spaceConfigStorageRegistry.getBatch(anyString())).thenReturn(new SpaceConfigStorageRegistryImpl.SpaceStorageBatchImpl(spaceConfigStorage));
+        when(spaceConfigStorageRegistry.exist(anyString())).thenReturn(true);
+
+        when(organizationalUnit.getName()).thenReturn("ou");
+        when(organizationalUnit.getSpace()).thenReturn(space);
+        when(space.getName()).thenReturn("ou");
+
+        doReturn(mock(org.uberfire.java.nio.file.Path.class)).when(service).getProjectRoot(Mockito.<ImportProject>any());
+        doReturn(mock(org.uberfire.java.nio.file.Path.class)).when(pathUtil).convert(Mockito.<org.uberfire.backend.vfs.Path>any());
+
+        doReturn(emptyList()).when(service).getBranches(Mockito.<org.uberfire.java.nio.file.Path>any(), any());
     }
 
     @Test
     public void testGetProjects_NullRepository() {
-        final Set<ImportProject> modules = service.getProjects(null);
+        final Set<ImportProject> modules = service.getProjects(organizationalUnit, null);
         assertNotNull(modules);
         assertEquals(0,
                      modules.size());
@@ -135,7 +189,7 @@ public class ProjectImportServiceImplTest {
 
     @Test
     public void testGetProjects_NullRepositoryUrl() {
-        final Set<ImportProject> modules = service.getProjects(new ExampleRepository(null));
+        final Set<ImportProject> modules = service.getProjects(organizationalUnit, new ExampleRepository(null));
         assertNotNull(modules);
         assertEquals(0,
                      modules.size());
@@ -143,15 +197,23 @@ public class ProjectImportServiceImplTest {
 
     @Test
     public void testGetProjects_EmptyRepositoryUrl() {
-        final Set<ImportProject> modules = service.getProjects(new ExampleRepository(""));
+        final Set<ImportProject> modules = service.getProjects(organizationalUnit, new ExampleRepository(""));
         assertNotNull(modules);
         assertEquals(0,
                      modules.size());
     }
 
+    @Test(expected = EmptyRemoteRepositoryException.class)
+    public void testGetProjects_EmptyRepository() {
+        doReturn(mock(GitRepository.class)).when(repositoryFactory).newRepository(Mockito.<RepositoryInfo>any());
+
+        service.getProjects(organizationalUnit,
+                            new ExampleRepository("https://github.com/myuser/myRepository"));
+    }
+
     @Test
     public void testGetProjects_WhiteSpaceRepositoryUrl() {
-        final Set<ImportProject> modules = service.getProjects(new ExampleRepository("   "));
+        final Set<ImportProject> modules = service.getProjects(organizationalUnit, new ExampleRepository("   "));
         assertNotNull(modules);
         assertEquals(0,
                      modules.size());
@@ -164,20 +226,20 @@ public class ProjectImportServiceImplTest {
         when(module.getRootPath()).thenReturn(moduleRoot);
         when(module.getModuleName()).thenReturn("module1");
         when(moduleRoot.toURI()).thenReturn("default:///module1");
-        when(metadataService.getTags(any(Path.class))).thenReturn(Arrays.asList("tag1",
-                                                                                "tag2"));
-        when(pathUtil.convert(any(Path.class))).thenCallRealMethod();
+        when(metadataService.getTags(Mockito.<Path>any())).thenReturn(Arrays.asList("tag1",
+                                                                                    "tag2"));
+        when(pathUtil.convert(Mockito.<Path>any())).thenCallRealMethod();
 
         final GitRepository repository = makeGitRepository();
-        when(repositoryFactory.newRepository(any(RepositoryInfo.class))).thenReturn(repository);
-        when(moduleService.getAllModules(any(Branch.class))).thenReturn(new HashSet<Module>() {{
+        when(repositoryFactory.newRepository(Mockito.<RepositoryInfo>any())).thenReturn(repository);
+        when(moduleService.getAllModules(Mockito.<Branch>any())).thenReturn(new HashSet<Module>() {{
             add(module);
         }});
-        doReturn(Collections.singletonList("master")).when(service).getBranches(any(org.uberfire.java.nio.file.Path.class),
-                                                                                any(Path.class));
+        doReturn(Collections.singletonList("master")).when(service).getBranches(Mockito.<org.uberfire.java.nio.file.Path>any(),
+                                                                                Mockito.<Path>any());
 
         String origin = "https://github.com/guvnorngtestuser1/guvnorng-playground.git";
-        final Set<ImportProject> modules = service.getProjects(new ExampleRepository(origin));
+        final Set<ImportProject> modules = service.getProjects(organizationalUnit, new ExampleRepository(origin));
         assertNotNull(modules);
         assertEquals(1,
                      modules.size());
@@ -199,22 +261,22 @@ public class ProjectImportServiceImplTest {
         when(module.getRootPath()).thenReturn(moduleRoot);
         when(module.getModuleName()).thenReturn("module1");
         when(moduleRoot.toURI()).thenReturn("default:///module1");
-        when(ioService.exists(any(org.uberfire.java.nio.file.Path.class))).thenReturn(true);
-        when(ioService.readAllString(any(org.uberfire.java.nio.file.Path.class))).thenReturn("This is custom description.\n\n This is a new line.");
-        when(metadataService.getTags(any(Path.class))).thenReturn(Arrays.asList("tag1",
-                                                                                "tag2"));
-        when(pathUtil.convert(any(Path.class))).thenCallRealMethod();
+        when(ioService.exists(Mockito.<org.uberfire.java.nio.file.Path>any())).thenReturn(true);
+        when(ioService.readAllString(Mockito.<org.uberfire.java.nio.file.Path>any())).thenReturn("This is custom description.\n\n This is a new line.");
+        when(metadataService.getTags(Mockito.<Path>any())).thenReturn(Arrays.asList("tag1",
+                                                                                    "tag2"));
+        when(pathUtil.convert(Mockito.<Path>any())).thenCallRealMethod();
 
         final GitRepository repository = makeGitRepository();
-        when(repositoryFactory.newRepository(any(RepositoryInfo.class))).thenReturn(repository);
-        when(moduleService.getAllModules(any(Branch.class))).thenReturn(new HashSet<Module>() {{
+        when(repositoryFactory.newRepository(Mockito.<RepositoryInfo>any())).thenReturn(repository);
+        when(moduleService.getAllModules(Mockito.<Branch>any())).thenReturn(new HashSet<Module>() {{
             add(module);
         }});
-        doReturn(Collections.singletonList("master")).when(service).getBranches(any(org.uberfire.java.nio.file.Path.class),
-                                                                                any(Path.class));
+        doReturn(Collections.singletonList("master")).when(service).getBranches(Mockito.<org.uberfire.java.nio.file.Path>any(),
+                                                                                Mockito.<Path>any());
 
         String origin = "https://github.com/guvnorngtestuser1/guvnorng-playground.git";
-        final Set<ImportProject> modules = service.getProjects(new ExampleRepository(origin));
+        final Set<ImportProject> modules = service.getProjects(organizationalUnit, new ExampleRepository(origin));
         assertNotNull(modules);
         assertEquals(1,
                      modules.size());
@@ -239,20 +301,20 @@ public class ProjectImportServiceImplTest {
         when(module.getModuleName()).thenReturn("module1");
         when(module.getPom()).thenReturn(pom);
         when(moduleRoot.toURI()).thenReturn("default:///module1");
-        when(metadataService.getTags(any(Path.class))).thenReturn(Arrays.asList("tag1",
-                                                                                "tag2"));
-        when(pathUtil.convert(any(Path.class))).thenCallRealMethod();
+        when(metadataService.getTags(Mockito.<Path>any())).thenReturn(Arrays.asList("tag1",
+                                                                                    "tag2"));
+        when(pathUtil.convert(Mockito.<Path>any())).thenCallRealMethod();
 
         final GitRepository repository = makeGitRepository();
-        when(repositoryFactory.newRepository(any(RepositoryInfo.class))).thenReturn(repository);
-        when(moduleService.getAllModules(any(Branch.class))).thenReturn(new HashSet<Module>() {{
+        when(repositoryFactory.newRepository(Mockito.<RepositoryInfo>any())).thenReturn(repository);
+        when(moduleService.getAllModules(Mockito.<Branch>any())).thenReturn(new HashSet<Module>() {{
             add(module);
         }});
-        doReturn(Collections.singletonList("master")).when(service).getBranches(any(org.uberfire.java.nio.file.Path.class),
-                                                                                any(Path.class));
+        doReturn(Collections.singletonList("master")).when(service).getBranches(Mockito.<org.uberfire.java.nio.file.Path>any(),
+                                                                                Mockito.<Path>any());
 
         String origin = "https://github.com/guvnorngtestuser1/guvnorng-playground.git";
-        final Set<ImportProject> modules = service.getProjects(new ExampleRepository(origin));
+        final Set<ImportProject> modules = service.getProjects(organizationalUnit, new ExampleRepository(origin));
         assertNotNull(modules);
         assertEquals(1,
                      modules.size());
@@ -287,7 +349,6 @@ public class ProjectImportServiceImplTest {
 
     @Test
     public void testImportProjects_ProjectImport() {
-        final OrganizationalUnit ou = mock(OrganizationalUnit.class);
         final ImportProject exProject1 = mock(ImportProject.class);
         final ImportProject exProject2 = mock(ImportProject.class);
         final List<ImportProject> exProjects = Arrays.asList(exProject1,
@@ -297,7 +358,6 @@ public class ProjectImportServiceImplTest {
         final Path module1Root = mock(Path.class);
         final Path module2Root = mock(Path.class);
 
-        when(ou.getName()).thenReturn("ou");
         when(exProject1.getName()).thenReturn("project1");
         when(exProject1.getRoot()).thenReturn(module1Root);
         when(exProject2.getName()).thenReturn("project2");
@@ -314,7 +374,7 @@ public class ProjectImportServiceImplTest {
         when(module1Root.toURI()).thenReturn("default:///module1");
         when(module2Root.toURI()).thenReturn("default:///module2");
 
-        when(ouService.getOrganizationalUnit(eq("ou"))).thenReturn(ou);
+        when(ouService.getOrganizationalUnit(eq("ou"))).thenReturn(organizationalUnit);
 
         WorkspaceProject project1 = mock(WorkspaceProject.class);
         when(project1.getName()).thenReturn("project1");
@@ -324,34 +384,27 @@ public class ProjectImportServiceImplTest {
         when(project2.getName()).thenReturn("project2");
         when(project2.getBranch()).thenReturn(master.get());
 
-        doReturn(project1).when(service).importProject(eq(ou),
-                                                       eq(exProject1));
+        doReturn(project1).when(service).importProject(eq(organizationalUnit), eq(exProject1));
 
-        doReturn(project2).when(service).importProject(eq(ou),
-                                                       eq(exProject2));
+        doReturn(project2).when(service).importProject(eq(organizationalUnit), eq(exProject2));
         final WorkspaceProject project = spy(new WorkspaceProject());
         doReturn("project").when(project).getName();
         doReturn(project).when(projectService).resolveProject(repository1);
 
-        final WorkspaceProjectContextChangeEvent event = service.importProjects(ou,
-                                                                                exProjects);
+        final WorkspaceProjectContextChangeEvent event = service.importProjects(organizationalUnit, exProjects);
 
-        assertEquals(ou,
-                     event.getOrganizationalUnit());
-        assertEquals(null,
-                     event.getWorkspaceProject());
+        assertEquals(organizationalUnit, event.getOrganizationalUnit());
+        assertEquals(null, event.getWorkspaceProject());
 
-        verify(ouService,
-               never()).createOrganizationalUnit(eq("ou"),
-                                                 eq(""));
-        verify(service,
-               times(2)).importProject(eq(ou),
-                                       any());
+        verify(ouService, never()).createOrganizationalUnit(eq("ou"), eq(""));
+        verify(service, times(2)).importProject(eq(organizationalUnit), any());
+
+        verify(spaceConfigStorage).startBatch();
+        verify(spaceConfigStorage).endBatch();
     }
 
     @Test
     public void importProjectWithCredentialsTest() {
-        final OrganizationalUnit organizationalUnit = mock(OrganizationalUnit.class);
         final Repository repo = mock(Repository.class);
         final WorkspaceProject project = mock(WorkspaceProject.class);
 
@@ -360,6 +413,17 @@ public class ProjectImportServiceImplTest {
         final String password = "fakePassword";
         final List<String> branches = Arrays.asList("master");
 
+        ImportProject importProject = mock(ImportProject.class, Answers.RETURNS_DEEP_STUBS.get());
+        when(importProject.getCredentials().getUsername()).thenReturn(username);
+        when(importProject.getCredentials().getPassword()).thenReturn(password);
+        when(importProject.getOrigin()).thenReturn(repositoryURL);
+        when(importProject.getSelectedBranches()).thenReturn(branches);
+
+        org.uberfire.java.nio.file.Path p = mock(org.uberfire.java.nio.file.Path.class);
+        when(p.getFileSystem()).thenReturn(mock(FileSystem.class));
+        doReturn(p).when(pathUtil).convert(Mockito.<org.uberfire.backend.vfs.Path>any());
+        when(service.getProjectRoot(Mockito.<ImportProject>any())).thenReturn(p);
+
         final ArgumentCaptor<RepositoryEnvironmentConfigurations> configCaptor = ArgumentCaptor.forClass(RepositoryEnvironmentConfigurations.class);
 
         when(repoService.createRepository(any(),
@@ -370,10 +434,7 @@ public class ProjectImportServiceImplTest {
         when(projectService.resolveProject(any(Repository.class))).thenReturn(project);
 
         final WorkspaceProject observedProject = service.importProject(organizationalUnit,
-                                                                       repositoryURL,
-                                                                       username,
-                                                                       password,
-                                                                       branches);
+                                                                       importProject);
 
         verify(repoService).createRepository(same(organizationalUnit),
                                              eq(GitRepository.SCHEME.toString()),
@@ -403,11 +464,15 @@ public class ProjectImportServiceImplTest {
         final String password = "fakePassword";
         final List<String> branches = Arrays.asList("master");
 
-        final OrganizationalUnit organizationalUnit = mock(OrganizationalUnit.class);
         final ImportProject importProject = mock(ImportProject.class);
         final Path rootPath = mock(Path.class);
+
         final org.uberfire.java.nio.file.Path convertedRootPath = mock(org.uberfire.java.nio.file.Path.class);
-        when(pathUtil.convert(any(Path.class))).thenReturn(convertedRootPath);
+        when(pathUtil.convert(Mockito.<Path>any())).thenReturn(convertedRootPath);
+        when(convertedRootPath.getFileSystem()).thenReturn(mock(FileSystem.class));
+
+        when(service.getProjectRoot(rootPath)).thenReturn(convertedRootPath);
+
         when(importProject.getCredentials()).thenReturn(new Credentials(username,
                                                                         password));
         when(importProject.getRoot()).thenReturn(rootPath);
@@ -416,14 +481,16 @@ public class ProjectImportServiceImplTest {
 
         when(importProject.getSelectedBranches()).thenReturn(branches);
 
+        when(service.getProjectRoot(importProject)).thenReturn(convertedRootPath);
         service.importProject(organizationalUnit,
                               importProject);
 
-        verify(service).importProject(organizationalUnit,
-                                      origin,
-                                      username,
-                                      password,
-                                      branches);
+        verify(repoService).createRepository(eq(organizationalUnit),
+                                             any(),
+                                             any(),
+                                             configurations.capture());
+
+        assertEquals(username, configurations.getValue().getUserName());
     }
 
     @Test
@@ -436,11 +503,13 @@ public class ProjectImportServiceImplTest {
         final String password = null;
         final List<String> branches = Arrays.asList("master");
 
-        final OrganizationalUnit organizationalUnit = mock(OrganizationalUnit.class);
         final ImportProject importProject = mock(ImportProject.class);
         final Path rootPath = mock(Path.class);
         final org.uberfire.java.nio.file.Path convertedRootPath = mock(org.uberfire.java.nio.file.Path.class);
-        when(pathUtil.convert(any(Path.class))).thenReturn(convertedRootPath);
+        when(pathUtil.convert(Mockito.<Path>any())).thenReturn(convertedRootPath);
+        when(convertedRootPath.getFileSystem()).thenReturn(mock(FileSystem.class));
+
+        when(service.getProjectRoot(rootPath)).thenReturn(convertedRootPath);
         when(importProject.getCredentials()).thenReturn(new Credentials(username,
                                                                         password));
         when(importProject.getRoot()).thenReturn(rootPath);
@@ -448,15 +517,10 @@ public class ProjectImportServiceImplTest {
         when(importProject.getOrigin()).thenReturn(origin);
 
         when(importProject.getSelectedBranches()).thenReturn(branches);
-
+        when(service.getProjectRoot(importProject)).thenReturn(convertedRootPath);
         service.importProject(organizationalUnit,
                               importProject);
 
-        verify(service).importProject(organizationalUnit,
-                                      origin,
-                                      username,
-                                      password,
-                                      branches);
         verify(repoService).createRepository(any(),
                                              any(),
                                              any(),
@@ -468,7 +532,6 @@ public class ProjectImportServiceImplTest {
 
     @Test
     public void importProjectWithoutCredentialsTest() {
-        final OrganizationalUnit organizationalUnit = mock(OrganizationalUnit.class);
         final Repository repo = mock(Repository.class);
         final WorkspaceProject project = mock(WorkspaceProject.class);
 
@@ -479,6 +542,17 @@ public class ProjectImportServiceImplTest {
 
         final ArgumentCaptor<RepositoryEnvironmentConfigurations> configCaptor = ArgumentCaptor.forClass(RepositoryEnvironmentConfigurations.class);
 
+        ImportProject importProject = mock(ImportProject.class, Answers.RETURNS_DEEP_STUBS.get());
+        when(importProject.getCredentials().getUsername()).thenReturn(username);
+        when(importProject.getCredentials().getPassword()).thenReturn(password);
+        when(importProject.getOrigin()).thenReturn(repositoryURL);
+        when(importProject.getSelectedBranches()).thenReturn(branches);
+
+        org.uberfire.java.nio.file.Path p = mock(org.uberfire.java.nio.file.Path.class);
+        when(p.getFileSystem()).thenReturn(mock(FileSystem.class));
+        doReturn(p).when(pathUtil).convert(Mockito.<org.uberfire.backend.vfs.Path>any());
+        when(service.getProjectRoot(Mockito.<ImportProject>any())).thenReturn(p);
+
         when(repoService.createRepository(any(),
                                           any(),
                                           any(),
@@ -486,10 +560,7 @@ public class ProjectImportServiceImplTest {
         when(projectService.resolveProject(any(Repository.class))).thenReturn(project);
 
         final WorkspaceProject observedProject = service.importProject(organizationalUnit,
-                                                                       repositoryURL,
-                                                                       username,
-                                                                       password,
-                                                                       branches);
+                                                                       importProject);
 
         verify(repoService).createRepository(same(organizationalUnit),
                                              eq(GitRepository.SCHEME.toString()),
@@ -518,8 +589,10 @@ public class ProjectImportServiceImplTest {
         organizationalUnit.getRepositories();
 
         final Path exampleRoot = mock(Path.class);
-        final org.uberfire.java.nio.file.Path exampleRootNioPath = mock(org.uberfire.java.nio.file.Path.class);
-        when(pathUtil.convert(exampleRoot)).thenReturn(exampleRootNioPath);
+        org.uberfire.java.nio.file.Path fspath = mock(org.uberfire.java.nio.file.Path.class);
+        final JGitFileSystem fileSystem = mock(JGitFileSystem.class);
+        doReturn(fileSystem).when(fspath).getFileSystem();
+        final org.uberfire.java.nio.file.Path exampleRootNioPath = fspath;
         String repoURL = "file:///some/repo/url";
         final ImportProject importProject = new ImportProject(exampleRoot,
                                                               "example",
@@ -541,6 +614,7 @@ public class ProjectImportServiceImplTest {
                                           eq(GitRepository.SCHEME.toString()),
                                           any(),
                                           any())).thenReturn(repository);
+        when(service.getProjectRoot(importProject)).thenReturn(exampleRootNioPath);
 
         final WorkspaceProject importedProject = service.importProject(organizationalUnit,
                                                                        importProject);
@@ -566,15 +640,17 @@ public class ProjectImportServiceImplTest {
         organizationalUnit.getRepositories();
 
         final Path exampleRoot = mock(Path.class);
-        final org.uberfire.java.nio.file.Path exampleRootNioPath = mock(org.uberfire.java.nio.file.Path.class);
-        when(pathUtil.convert(exampleRoot)).thenReturn(exampleRootNioPath);
+        org.uberfire.java.nio.file.Path fspath = mock(org.uberfire.java.nio.file.Path.class);
+        final JGitFileSystem fileSystem = mock(JGitFileSystem.class);
+        doReturn(fileSystem).when(fspath).getFileSystem();
+        final org.uberfire.java.nio.file.Path exampleRootNioPath = fspath;
         String repoURL = "file:///C:/some/repo/url";
         final ImportProject importProject = new ImportProject(exampleRoot,
                                                               "example",
                                                               "description",
                                                               repoURL,
                                                               emptyList());
-
+        doReturn(emptyList()).when(service).getBranches(Mockito.<org.uberfire.java.nio.file.Path>any(), any());
         when(pathUtil.getNiogitRepoPath(any())).thenReturn(repoURL);
 
         final Repository repository = new GitRepository("example",
@@ -589,7 +665,7 @@ public class ProjectImportServiceImplTest {
                                           eq(GitRepository.SCHEME.toString()),
                                           any(),
                                           any())).thenReturn(repository);
-
+        when(service.getProjectRoot(importProject)).thenReturn(exampleRootNioPath);
         final WorkspaceProject importedProject = service.importProject(organizationalUnit,
                                                                        importProject);
 
@@ -625,14 +701,14 @@ public class ProjectImportServiceImplTest {
                                                                                        true);
         final org.uberfire.java.nio.file.Path repoRoot = exampleRootNioPath.getParent();
         when(fs.getRootDirectories()).thenReturn(() -> Stream.of(repoRoot).iterator());
-        when(pathUtil.convert(exampleRoot)).thenReturn(exampleRootNioPath);
-        when(pathUtil.stripProtocolAndBranch(any())).then(inv -> realPathUtil.stripProtocolAndBranch(inv.getArgumentAt(0,
+
+        when(pathUtil.stripProtocolAndBranch(any())).then(inv -> realPathUtil.stripProtocolAndBranch(inv.getArgument(0,
                                                                                                                        String.class)));
-        when(pathUtil.stripRepoNameAndSpace(any())).then(inv -> realPathUtil.stripRepoNameAndSpace(inv.getArgumentAt(0,
+        when(pathUtil.stripRepoNameAndSpace(any())).then(inv -> realPathUtil.stripRepoNameAndSpace(inv.getArgument(0,
                                                                                                                      String.class)));
-        when(pathUtil.convert(any(org.uberfire.java.nio.file.Path.class))).then(inv -> realPathUtil.convert(inv.getArgumentAt(0,
-                                                                                                                              org.uberfire.java.nio.file.Path.class)));
-        when(pathUtil.extractBranch(any())).then(inv -> realPathUtil.extractBranch(inv.getArgumentAt(0,
+        when(pathUtil.convert(Mockito.<org.uberfire.java.nio.file.Path>any())).then(inv -> realPathUtil.convert(inv.getArgument(0,
+                                                                                                                                org.uberfire.java.nio.file.Path.class)));
+        when(pathUtil.extractBranch(any())).then(inv -> realPathUtil.extractBranch(inv.getArgument(0,
                                                                                                      String.class)));
 
         String repoURL = "file:///some/repo/url";
@@ -641,7 +717,7 @@ public class ProjectImportServiceImplTest {
                                                               "description",
                                                               repoURL,
                                                               emptyList());
-
+        when(service.getProjectRoot(importProject)).thenReturn(exampleRootNioPath);
         when(pathUtil.getNiogitRepoPath(any())).thenReturn(repoURL);
 
         final Repository repository = new GitRepository("example",
@@ -652,10 +728,11 @@ public class ProjectImportServiceImplTest {
                                                                          mock(Path.class)),
                                                               new Module());
         when(projectService.resolveProject(repository)).thenReturn(project);
-        when(repoService.createRepository(same(organizationalUnit),
-                                          eq(GitRepository.SCHEME.toString()),
-                                          any(),
-                                          any())).thenReturn(repository);
+
+        doReturn(repository).when(repoService).createRepository(same(organizationalUnit),
+                                                                eq(GitRepository.SCHEME.toString()),
+                                                                any(),
+                                                                any());
 
         final WorkspaceProject importedProject = service.importProject(organizationalUnit,
                                                                        importProject);
