@@ -50,7 +50,6 @@ import org.guvnor.structure.repositories.RepositoryService;
 import org.jboss.errai.common.client.api.Caller;
 import org.jboss.errai.common.client.api.RemoteCallback;
 import org.jboss.errai.ioc.client.api.ManagedInstance;
-import org.jboss.errai.security.shared.api.identity.User;
 import org.jboss.errai.security.shared.exception.UnauthorizedException;
 import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.kie.soup.commons.validation.PortablePreconditions;
@@ -75,9 +74,11 @@ import org.slf4j.Logger;
 import org.uberfire.backend.vfs.ObservablePath;
 import org.uberfire.backend.vfs.Path;
 import org.uberfire.backend.vfs.VFSService;
+import org.uberfire.client.mvp.PerspectiveManager;
 import org.uberfire.client.mvp.PlaceManager;
 import org.uberfire.client.mvp.PlaceStatus;
 import org.uberfire.client.promise.Promises;
+import org.uberfire.client.util.Cookie;
 import org.uberfire.client.workbench.events.PlaceGainFocusEvent;
 import org.uberfire.ext.editor.commons.client.event.ConcurrentDeleteAcceptedEvent;
 import org.uberfire.ext.editor.commons.client.event.ConcurrentRenameAcceptedEvent;
@@ -185,6 +186,10 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
 
     private PlaceRequest changeRequestReviewScreen = null;
 
+    private Cookie cookie;
+
+    private PerspectiveManager perspectiveManager;
+
     public LibraryPlaces() {
     }
 
@@ -211,7 +216,9 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
                          final Promises promises,
                          final OrganizationalUnitController organizationalUnitController,
                          final Caller<OrganizationalUnitService> organizationalUnitService,
-                         final Logger logger) {
+                         final Logger logger,
+                         final Cookie cookie,
+                         final PerspectiveManager perspectiveManager) {
 
         this.breadcrumbs = breadcrumbs;
         this.ts = ts;
@@ -236,6 +243,8 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
         this.organizationalUnitController = organizationalUnitController;
         this.organizationalUnitService = organizationalUnitService;
         this.logger = logger;
+        this.cookie = cookie;
+        this.perspectiveManager = perspectiveManager;
     }
 
     @PostConstruct
@@ -261,12 +270,20 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
     private static LibraryPlaces self;
 
     public static Object nativeGoToSpace(final String spaceName) {
-        return self.promises.promisify(self.organizationalUnitService, s -> {
-            return s.getOrganizationalUnit(spaceName);
-        }).then(space -> {
-            self.projectContextChangeEvent.fire(new WorkspaceProjectContextChangeEvent(space));
-            return self.goToLibrary();
-        });
+        return self.promises
+                .promisify(self.organizationalUnitService,
+                           s -> {
+                               return s.getOrganizationalUnit(spaceName);
+                           })
+                .then(space -> {
+                    if (space == null) {
+                        self.cookie.clear(self.getLastSpaceCookie());
+                    } else {
+                        self.cookie.set(self.getLastSpaceCookie(), spaceName);
+                    }
+                    self.projectContextChangeEvent.fire(new WorkspaceProjectContextChangeEvent(space));
+                    return self.goToLibrary();
+                });
     }
 
     public native void expose() /*-{
@@ -346,6 +363,18 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
         }
     }
 
+    private String getLastSpaceCookie() {
+        return sessionInfo.getIdentity().getIdentifier() + "_lastSpace";
+    }
+
+    private String getLastProjectCookie() {
+        return sessionInfo.getIdentity().getIdentifier() + "_lastProject";
+    }
+
+    private String getProjectLastBranchCookie(String projectName) {
+        return sessionInfo.getIdentity().getIdentifier() + "_" + projectName + "_lastBranch";
+    }
+
     public void deleteProject(final WorkspaceProject project,
                               final HasBusyIndicator view) {
         repositoryService.call(v -> view.hideBusyIndicator(),
@@ -377,10 +406,7 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
     }
 
     private boolean isLibraryPerspectiveOpen() {
-        final PlaceStatus statusPerspective = placeManager.getStatus(LIBRARY_PERSPECTIVE);
-        final PlaceStatus statusPerspectiveWithoutRefresh = placeManager.getStatus(getLibraryPlaceRequestWithoutRefresh());
-        return statusPerspective.equals(PlaceStatus.OPEN)
-                || statusPerspectiveWithoutRefresh.equals(PlaceStatus.OPEN);
+        return perspectiveManager.getCurrentPerspective().getPlace().getIdentifier().equals(LIBRARY_PERSPECTIVE);
     }
 
     public void onPreferencesSave(@Observes PreferencesCentralSaveEvent event) {
@@ -395,18 +421,6 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
         }
     }
 
-    PlaceRequest getLibraryPlaceRequestWithoutRefresh() {
-        return getPlaceRequestWithoutRefresh(LIBRARY_PERSPECTIVE);
-    }
-
-    private PlaceRequest getPlaceRequestWithoutRefresh(String placeId) {
-        final Map<String, String> params = new HashMap<>();
-        params.put("refresh",
-                   "false");
-        return new DefaultPlaceRequest(placeId,
-                                       params);
-    }
-
     public void refresh(final Command callback) {
         breadcrumbs.clearBreadcrumbs(LibraryPlaces.LIBRARY_PERSPECTIVE);
         translationUtils.refresh(callback::execute);
@@ -432,23 +446,34 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
     public Promise<Void> goToLibrary() {
         if (!projectContext.getActiveOrganizationalUnit().isPresent()) {
             return promises.create((res, rej) -> {
-                libraryService.call(
-                        (RemoteCallback<OrganizationalUnit>) organizationalUnit -> {
-                            this.goToOrganizationalUnits();
-                            res.onInvoke((IThenable<Void>) null);
-                        },
-                        (message, throwable) -> {
-                            try {
-                                throw throwable;
-                            } catch (UnauthorizedException ue) {
-                                this.goToOrganizationalUnits();
-                                res.onInvoke((IThenable<Void>) null);
-                                return false;
-                            } catch (Throwable t) {
-                                rej.onInvoke(null);
-                                return true; // Let default error handling happen.
-                            }
-                        }).getDefaultOrganizationalUnit();
+                String lastSpace = cookie.get(self.getLastSpaceCookie());
+                String lastProject = cookie.get(self.getLastProjectCookie());
+                String lastBranch = cookie.get(self.getProjectLastBranchCookie(lastProject));
+
+                if (!lastProject.equals("") && !lastBranch.equals("")) {
+                    goToProject(lastSpace, lastProject, lastBranch);
+                    return;
+                }
+                if (!lastSpace.equals("")) {
+                    nativeGoToSpace(lastSpace);
+                    return;
+                }
+                libraryService.call((RemoteCallback<OrganizationalUnit>) organizationalUnit -> {
+                                        this.goToOrganizationalUnits();
+                                        res.onInvoke((IThenable<Void>) null);
+                                    },
+                                    (message, throwable) -> {
+                                        try {
+                                            throw throwable;
+                                        } catch (UnauthorizedException ue) {
+                                            this.goToOrganizationalUnits();
+                                            res.onInvoke((IThenable<Void>) null);
+                                            return false;
+                                        } catch (Throwable t) {
+                                            rej.onInvoke(null);
+                                            return true; // Let default error handling happen.
+                                        }
+                                    }).getDefaultOrganizationalUnit();
             });
         } else {
             setupLibraryPerspective();
@@ -481,11 +506,18 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
         if (projectContext.getActiveWorkspaceProject()
                 .map(activeProject -> !activeProject.equals(project))
                 .orElse(true)) {
+            final String lastBranch = cookie.get(getProjectLastBranchCookie(project.getName()));
+            cookie.set(getLastProjectCookie(), project.getName());
             closeAllPlacesOrNothing(() -> {
                 projectContextChangeEvent.fire(new WorkspaceProjectContextChangeEvent(project,
                                                                                       project.getMainModule()));
-                goToProject(project,
-                            project.getBranch());
+
+                if (!lastBranch.equals("")) {
+                    goToProject(project.getSpace().getName(), project.getName(), lastBranch);
+                } else {
+                    goToProject(project,
+                                project.getBranch());
+                }
             });
         } else {
             goToProject();
@@ -494,7 +526,10 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
 
     public void goToProject(final WorkspaceProject project,
                             final Branch branch) {
-        projectService.call((RemoteCallback<WorkspaceProject>) this::goToProject,
+        projectService.call((RemoteCallback<WorkspaceProject>) pro -> {
+                                cookie.set(getProjectLastBranchCookie(project.getName()), branch.getName(), 604800);
+                                goToProject(pro);
+                            },
                             (o, throwable) -> {
                                 logger.info("Project " + project.getName() + " branch " + branch.getName() + " not found.");
                                 return false;
@@ -507,6 +542,28 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
         });
     }
 
+    public void goToProject(final Path projectPath) {
+        projectService.call((RemoteCallback<WorkspaceProject>) project -> {
+            goToProject(project, project.getBranch());
+        }, (o, throwable) -> {
+            notificationEvent.fire(new NotificationEvent(ts.format(LibraryConstants.InvalidProjectPath),
+                                                         NotificationEvent.NotificationType.ERROR));
+            return false;
+        }).resolveProject(projectPath);
+    }
+
+    public void goToProject(final String spaceName, final String projectName, final String branchName) {
+        projectService.call((RemoteCallback<WorkspaceProject>) project -> {
+            goToProject(project);
+        }, (o, throwable) -> {
+            logger.info("Project " + projectName + " branch " + branchName + " not found.");
+            self.cookie.clear(self.getLastProjectCookie());
+            self.cookie.clear(self.getProjectLastBranchCookie(projectName));
+            goToOrganizationalUnits();
+            return false;
+        }).resolveProject(new Space(spaceName), projectName, branchName);
+    }
+
     private void goToProject(final Command callback) {
         libraryBreadcrumbs.setupForProject(projectContext.getActiveWorkspaceProject()
                                                    .orElseThrow(() -> new IllegalStateException("Cannot go to project when no project is active.")));
@@ -717,7 +774,7 @@ public class LibraryPlaces implements WorkspaceProjectContextChangeHandler {
     public boolean isThisUserAccessingThisRepository(final String userIdentifier,
                                                      final Repository repository) {
         return isThisRepositoryBeingAccessed(repository)
-            && sessionInfo.getIdentity().getIdentifier().equals(userIdentifier);
+                && sessionInfo.getIdentity().getIdentifier().equals(userIdentifier);
     }
 
     public boolean isThisRepositoryBeingAccessed(final Repository repository) {
