@@ -52,7 +52,7 @@ import org.mockito.ArgumentCaptor;
 import org.mockito.Mock;
 import org.mockito.Spy;
 import org.mockito.invocation.InvocationOnMock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 import org.mockito.stubbing.Answer;
 import org.slf4j.Logger;
 import org.uberfire.mocks.CallerMock;
@@ -61,10 +61,10 @@ import org.uberfire.mvp.Command;
 import org.uberfire.workbench.events.NotificationEvent;
 
 import static org.junit.Assert.*;
-import static org.mockito.Matchers.any;
+import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.Mockito.*;
 
-@RunWith(MockitoJUnitRunner.class)
+@RunWith(MockitoJUnitRunner.Silent.class)
 public class ContainerPresenterTest {
 
     @Mock
@@ -204,6 +204,7 @@ public class ContainerPresenterTest {
     @Test
     public void testStartContainer() {
         presenter.loadContainers(containerSpecData);
+
         presenter.startContainer();
 
         verify(view).setContainerStartState(State.ENABLED);
@@ -314,8 +315,7 @@ public class ContainerPresenterTest {
     public void testLoadContainersEmpty() {
         presenter.loadContainers(containerSpecData);
 
-        verifyLoad(true,
-                   1);
+        verifyLoad(true, 1, false);
     }
 
     @Test
@@ -330,14 +330,12 @@ public class ContainerPresenterTest {
         presenter.setContainerSpec(containerSpec1);
         presenter.loadContainers(containerSpecData);
 
-        verifyLoad(true,
-                   0);
+        verifyLoad(true, 0, false);
 
         presenter.setContainerSpec(containerSpec);
         presenter.loadContainers(containerSpecData);
 
-        verifyLoad(true,
-                   1);
+        verifyLoad(true, 1, false);
 
     }
 
@@ -351,8 +349,7 @@ public class ContainerPresenterTest {
         presenter.loadContainers(containerSpecData);
         presenter.refresh();
 
-        verifyLoad(true,
-                   2);
+        verifyLoad(true, 2, false);
     }
 
     @Test
@@ -366,8 +363,7 @@ public class ContainerPresenterTest {
         containerSpecData.getContainers().add(container);
         presenter.loadContainers(containerSpecData);
 
-        verifyLoad(true,
-                   1);
+        verifyLoad(true, 1, false);
     }
 
     @Test
@@ -382,12 +378,29 @@ public class ContainerPresenterTest {
         containerSpecData.getContainers().add(container);
         presenter.loadContainers(containerSpecData);
 
-        verifyLoad(false,
-                   1);
+        verifyLoad(false, 1, false);
     }
 
-    private void verifyLoad(boolean empty,
-                            int times) {
+    @Test
+    public void testLoadContainersHasFailed() {
+        final Container container = new Container("containerSpecId",
+                                                  "containerName",
+                                                  new ServerInstanceKey(),
+                                                  Collections.<Message>emptyList(),
+                                                  null,
+                                                  null);
+        container.setStatus(KieContainerStatus.FAILED);
+        containerSpecData.getContainers().add(container);
+        assertNull(container.getResolvedReleasedId());
+        presenter.loadContainers(containerSpecData);
+
+        assertEquals(KieContainerStatus.FAILED, containerSpecData.getContainerSpec().getStatus());
+        assertNotNull(container.getResolvedReleasedId());
+
+        verifyLoad(false, 1, true);
+    }
+
+    private void verifyLoad(boolean empty, int times, boolean hasFailed) {
         verify(containerStatusEmptyPresenter,
                times(times)).setup(containerSpec);
         verify(containerRemoteStatusPresenter,
@@ -421,8 +434,11 @@ public class ContainerPresenterTest {
 
         verify(view,
                times(times)).setContainerStartState(State.DISABLED);
-        verify(view,
-               times(times)).setContainerStopState(State.ENABLED);
+        if (!hasFailed) {
+            verify(view, times(times)).setContainerStopState(State.ENABLED);
+        } else {
+            verify(view, times(times)).setContainerStopState(State.DISABLED);
+        }
 
         verify(containerProcessConfigPresenter,
                times(times)).setup(containerSpec,
@@ -440,8 +456,7 @@ public class ContainerPresenterTest {
 
         presenter.load(new ContainerSpecSelected(containerSpec));
 
-        verifyLoad(true,
-                   1);
+        verifyLoad(true, 1, false);
     }
 
     @Test
@@ -514,8 +529,7 @@ public class ContainerPresenterTest {
 
         presenter.onRefresh(new RefreshRemoteServers(containerSpec));
 
-        verifyLoad(true,
-                   1);
+        verifyLoad(true, 1, false);
     }
 
     @Test
@@ -599,7 +613,7 @@ public class ContainerPresenterTest {
 
         verify(view).enableRemoveButton();
         verify(view).setContainerStartState(State.DISABLED);
-        verify(view).setContainerStopState(State.ENABLED);
+        verify(view).setContainerStopState(State.DISABLED);
         verify(view).disableToggleActivationButton();
     }
 
