@@ -42,7 +42,7 @@ import org.kie.workbench.common.screens.server.management.service.SpecManagement
 import org.mockito.Mock;
 import org.mockito.Spy;
 import org.mockito.invocation.InvocationOnMock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 import org.mockito.stubbing.Answer;
 import org.slf4j.Logger;
 import org.uberfire.ext.widgets.core.client.wizards.WizardPageStatusChangeEvent;
@@ -51,11 +51,11 @@ import org.uberfire.mocks.EventSourceMock;
 
 import static org.junit.Assert.*;
 import static org.kie.workbench.common.screens.server.management.client.wizard.container.NewContainerFormPresenter.SNAPSHOT;
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.anyString;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.anyString;
 import static org.mockito.Mockito.*;
 
-@RunWith(MockitoJUnitRunner.class)
+@RunWith(MockitoJUnitRunner.Silent.class)
 public class NewContainerFormPresenterTest {
 
     private final Collection<ContentChangeHandler> contentChangeHandlers = new ArrayList<ContentChangeHandler>();
