@@ -16,9 +16,7 @@
 
 package org.kie.workbench.common.stunner.client.lienzo.canvas.controls;
 
-import java.util.Arrays;
 import java.util.Collections;
-import java.util.List;
 
 import com.ait.lienzo.client.core.shape.Group;
 import com.ait.lienzo.client.core.shape.MultiPath;
@@ -40,22 +38,26 @@ import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.stunner.client.lienzo.canvas.wires.WiresCanvas;
+import org.kie.workbench.common.stunner.client.lienzo.canvas.wires.WiresCanvasView;
 import org.kie.workbench.common.stunner.client.lienzo.canvas.wires.WiresUtils;
 import org.kie.workbench.common.stunner.client.lienzo.shape.view.wires.WiresShapeView;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
-import org.kie.workbench.common.stunner.core.client.canvas.Layer;
-import org.kie.workbench.common.stunner.core.client.canvas.command.DefaultCanvasCommandFactory;
-import org.kie.workbench.common.stunner.core.client.canvas.command.UpdateControlPointPositionCommand;
+import org.kie.workbench.common.stunner.core.client.canvas.CanvasPanel;
 import org.kie.workbench.common.stunner.core.client.canvas.command.UpdateElementPositionCommand;
 import org.kie.workbench.common.stunner.core.client.canvas.event.ShapeLocationsChangedEvent;
+import org.kie.workbench.common.stunner.core.client.canvas.event.selection.CanvasSelectionEvent;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommand;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandFactory;
+import org.kie.workbench.common.stunner.core.client.command.CanvasCommandFactoryStub;
 import org.kie.workbench.common.stunner.core.client.command.CanvasCommandManager;
+import org.kie.workbench.common.stunner.core.client.event.keyboard.KeyboardEvent;
 import org.kie.workbench.common.stunner.core.client.shape.Shape;
 import org.kie.workbench.common.stunner.core.client.shape.ShapeViewExtStub;
 import org.kie.workbench.common.stunner.core.client.shape.view.HasControlPoints;
 import org.kie.workbench.common.stunner.core.client.shape.view.HasEventHandlers;
 import org.kie.workbench.common.stunner.core.client.shape.view.ShapeView;
+import org.kie.workbench.common.stunner.core.client.shape.view.event.DragEvent;
+import org.kie.workbench.common.stunner.core.client.shape.view.event.DragHandler;
 import org.kie.workbench.common.stunner.core.client.shape.view.event.MouseEnterHandler;
 import org.kie.workbench.common.stunner.core.client.shape.view.event.ViewEventType;
 import org.kie.workbench.common.stunner.core.client.shape.view.event.ViewHandler;
@@ -66,11 +68,8 @@ import org.kie.workbench.common.stunner.core.graph.Edge;
 import org.kie.workbench.common.stunner.core.graph.Element;
 import org.kie.workbench.common.stunner.core.graph.Graph;
 import org.kie.workbench.common.stunner.core.graph.Node;
+import org.kie.workbench.common.stunner.core.graph.content.Bounds;
 import org.kie.workbench.common.stunner.core.graph.content.definition.DefinitionSet;
-import org.kie.workbench.common.stunner.core.graph.content.view.BoundImpl;
-import org.kie.workbench.common.stunner.core.graph.content.view.BoundsImpl;
-import org.kie.workbench.common.stunner.core.graph.content.view.ControlPoint;
-import org.kie.workbench.common.stunner.core.graph.content.view.ControlPointImpl;
 import org.kie.workbench.common.stunner.core.graph.content.view.Point2D;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
 import org.kie.workbench.common.stunner.core.graph.content.view.ViewConnector;
@@ -78,13 +77,16 @@ import org.kie.workbench.common.stunner.core.graph.processing.index.Index;
 import org.kie.workbench.common.stunner.core.util.UUID;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Mock;
+import org.mockito.Mockito;
 import org.uberfire.mocks.EventSourceMock;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.eq;
+import static org.mockito.ArgumentCaptor.forClass;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.eq;
+import static org.mockito.Mockito.atLeastOnce;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.times;
@@ -97,18 +99,7 @@ public class LocationControlImplTest {
     private static final String ROOT_UUID = "root-uuid1";
     private static final String ELEMENT_UUID = "element-uuid1";
     private static final String DEF_ID = "def-id";
-    private static final BoundsImpl GRAPH_BOUNDS = new BoundsImpl(
-            new BoundImpl(1d,
-                          2d),
-            new BoundImpl(3000d,
-                          4000d)
-    );
-    private static final BoundsImpl ELEMENT_BOUNDS = new BoundsImpl(
-            new BoundImpl(10d,
-                          20d),
-            new BoundImpl(30d,
-                          40d)
-    );
+    private static final Bounds ELEMENT_BOUNDS = Bounds.create(10d, 20d, 30d, 40d);
 
     @Mock
     private CanvasCommandManager<AbstractCanvasHandler> commandManager;
@@ -120,7 +111,10 @@ public class LocationControlImplTest {
     private WiresCanvas canvas;
 
     @Mock
-    private Layer layer;
+    private WiresCanvasView canvasView;
+
+    @Mock
+    private CanvasPanel canvasPanel;
 
     @Mock
     private WiresManager wiresManager;
@@ -149,6 +143,12 @@ public class LocationControlImplTest {
     @Mock
     private Node element;
 
+    @Mock
+    private Node<View<?>, Edge> node;
+
+    @Mock
+    private View nodeContent;
+
     @Mock
     private View elementContent;
 
@@ -167,6 +167,9 @@ public class LocationControlImplTest {
     @Mock
     private EventSourceMock<ShapeLocationsChangedEvent> shapeLocationsChangedEvent;
 
+    @Mock
+    private EventSourceMock<CanvasSelectionEvent> canvasSelectionEvent;
+
     private CanvasCommandFactory<AbstractCanvasHandler> canvasCommandFactory;
     private ShapeViewExtStub shapeView;
     private LocationControlImpl tested;
@@ -174,7 +177,7 @@ public class LocationControlImplTest {
     @Before
     @SuppressWarnings("unchecked")
     public void setup() throws Exception {
-        this.canvasCommandFactory = new DefaultCanvasCommandFactory(null, null);
+        this.canvasCommandFactory = new CanvasCommandFactoryStub();
 
         this.shapeView = spy(new ShapeViewExtStub(shapeEventHandler,
                                                   hasControlPoints));
@@ -188,22 +191,23 @@ public class LocationControlImplTest {
         when(elementContent.getDefinition()).thenReturn(definition);
         when(elementContent.getBounds()).thenReturn(ELEMENT_BOUNDS);
         when(graph.getContent()).thenReturn(graphContent);
-        when(graphContent.getBounds()).thenReturn(GRAPH_BOUNDS);
         when(diagram.getGraph()).thenReturn(graph);
         when(diagram.getMetadata()).thenReturn(metadata);
         when(metadata.getCanvasRootUUID()).thenReturn(ROOT_UUID);
+        when(canvasHandler.getAbstractCanvas()).thenReturn(canvas);
         when(canvasHandler.getCanvas()).thenReturn(canvas);
-        when(canvas.getLayer()).thenReturn(layer);
+        when(canvas.getView()).thenReturn(canvasView);
         when(canvas.getShape(eq(ELEMENT_UUID))).thenReturn(shape);
         when(canvas.getShapes()).thenReturn(Collections.singletonList(shape));
         when(canvas.getWiresManager()).thenReturn(wiresManager);
+        when(canvasView.getPanel()).thenReturn(canvasPanel);
         when(shape.getUUID()).thenReturn(ELEMENT_UUID);
         when(shape.getShapeView()).thenReturn(shapeView);
-        when(shapeEventHandler.supports(any(ViewEventType.class))).thenReturn(true);
+        when(shapeEventHandler.supports(Mockito.<ViewEventType>any())).thenReturn(true);
         when(wiresManager.getSelectionManager()).thenReturn(selectionManager);
         when(selectionManager.getControl()).thenReturn(wiresCompositeControl);
 
-        this.tested = new LocationControlImpl(canvasCommandFactory, shapeLocationsChangedEvent);
+        this.tested = new LocationControlImpl(canvasCommandFactory, shapeLocationsChangedEvent, canvasSelectionEvent);
         tested.setCommandManagerProvider(() -> commandManager);
     }
 
@@ -222,24 +226,27 @@ public class LocationControlImplTest {
         tested.register(element);
         assertTrue(tested.isRegistered(element));
         verify(shapeView, times(1)).setDragEnabled(eq(true));
-        ArgumentCaptor<BoundingBox> bbCaptor = ArgumentCaptor.forClass(BoundingBox.class);
-        verify(wiresCompositeControl, times(1)).setBoundsConstraint(bbCaptor.capture());
-        BoundingBox bb = bbCaptor.getValue();
-        assertEquals(1.0d, bb.getMinX(), 0d);
-        assertEquals(2.0d, bb.getMinY(), 0d);
-        assertEquals(3000.0d, bb.getMaxX(), 0d);
-        assertEquals(4000.0d, bb.getMaxY(), 0d);
-        verify(shapeView, times(1)).setDragBounds(1.0d, 2.0d, 3000d, 4000d);
         verify(shapeEventHandler,
                times(1)).supports(eq(ViewEventType.MOUSE_ENTER));
         verify(shapeEventHandler,
                times(1)).addHandler(eq(ViewEventType.MOUSE_ENTER),
-                                    any(MouseEnterHandler.class));
+                                    Mockito.<MouseEnterHandler>any());
         verify(shapeEventHandler,
                times(1)).supports(eq(ViewEventType.MOUSE_EXIT));
         verify(shapeEventHandler,
                times(1)).addHandler(eq(ViewEventType.MOUSE_EXIT),
-                                    any(MouseEnterHandler.class));
+
+                                    Mockito.<MouseEnterHandler>any());
+
+        //testing drag handler to select the moving element
+        ArgumentCaptor<DragHandler> dragHandlerArgumentCaptor = forClass(DragHandler.class);
+        verify(shapeEventHandler).addHandler(eq(ViewEventType.DRAG), dragHandlerArgumentCaptor.capture());
+        dragHandlerArgumentCaptor.getValue().start(mock(DragEvent.class));
+        dragHandlerArgumentCaptor.getValue().end(mock(DragEvent.class));
+
+        ArgumentCaptor<CanvasSelectionEvent> canvasSelectionEventArgumentCaptor = forClass(CanvasSelectionEvent.class);
+        verify(canvasSelectionEvent).fire(canvasSelectionEventArgumentCaptor.capture());
+        assertTrue(canvasSelectionEventArgumentCaptor.getValue().getIdentifiers().contains(element.getUUID()));
     }
 
     @Test
@@ -258,8 +265,6 @@ public class LocationControlImplTest {
         final Edge connectorEdge = mock(Edge.class);
         final com.ait.lienzo.client.core.types.Point2D controlPointLienzo = new com.ait.lienzo.client.core.types.Point2D(100, 100);
         final Point2DArray controlPointsLienzo = new Point2DArray(controlPointLienzo);
-        final ControlPoint controlPoint = new ControlPointImpl(new Point2D(0, 0), 0);
-        final List<ControlPoint> controlPoints = Arrays.asList(controlPoint);
         final ViewConnector viewConnector = mock(ViewConnector.class);
         Group parentGroup = mock(Group.class);
         BoundingBox parentBB = new BoundingBox(0, 0, 200, 200);
@@ -288,18 +293,17 @@ public class LocationControlImplTest {
         when(shape.getShapeView()).thenReturn(wiresShape);
         when(graphIndex.getEdge(connectorUUID)).thenReturn(connectorEdge);
         when(connectorEdge.getContent()).thenReturn(viewConnector);
-        when(viewConnector.getControlPoints()).thenReturn(controlPoints);
         when(connectorGroup.getUserData()).thenReturn(new WiresUtils.UserData(connectorUUID, ""));
 
         tested.init(canvasHandler);
         tested.register(element);
         Point2D location = new Point2D(45d, 65.5d);
         tested.move(new Element[]{element}, new Point2D[]{location});
-        ArgumentCaptor<CanvasCommand> commandArgumentCaptor = ArgumentCaptor.forClass(CanvasCommand.class);
+        ArgumentCaptor<CanvasCommand> commandArgumentCaptor = forClass(CanvasCommand.class);
         verify(commandManager, times(1)).execute(eq(canvasHandler),
                                                  commandArgumentCaptor.capture());
 
-        ArgumentCaptor<ShapeLocationsChangedEvent> shapeLocationsChangedEventCaptor = ArgumentCaptor.forClass(ShapeLocationsChangedEvent.class);
+        ArgumentCaptor<ShapeLocationsChangedEvent> shapeLocationsChangedEventCaptor = forClass(ShapeLocationsChangedEvent.class);
         verify(shapeLocationsChangedEvent, times(1)).fire(shapeLocationsChangedEventCaptor.capture());
         assertTrue(shapeLocationsChangedEventCaptor.getValue() instanceof ShapeLocationsChangedEvent);
 
@@ -308,12 +312,6 @@ public class LocationControlImplTest {
         UpdateElementPositionCommand updateElementPositionCommand = (UpdateElementPositionCommand) command.getCommands().get(0);
         assertEquals(element, updateElementPositionCommand.getElement());
         assertEquals(location, updateElementPositionCommand.getLocation());
-
-        //assert child connector control point move
-        final UpdateControlPointPositionCommand controlPointCommand = (UpdateControlPointPositionCommand) command.getCommands().get(1);
-        assertEquals(controlPoint, controlPointCommand.getControlPoint());
-        assertEquals(new Point2D(controlPointLienzo.getX(), controlPointLienzo.getY()), controlPointCommand.getPosition());
-        assertEquals(connectorEdge, controlPointCommand.getCandidate());
     }
 
     @Test
@@ -329,7 +327,7 @@ public class LocationControlImplTest {
         final com.ait.lienzo.client.core.types.Point2D point = new com.ait.lienzo.client.core.types.Point2D(40d, 50d);
         locationAcceptor.accept(new WiresContainer[]{wiresContainer},
                                 new com.ait.lienzo.client.core.types.Point2D[]{point});
-        ArgumentCaptor<CanvasCommand> commandArgumentCaptor = ArgumentCaptor.forClass(CanvasCommand.class);
+        ArgumentCaptor<CanvasCommand> commandArgumentCaptor = forClass(CanvasCommand.class);
         verify(commandManager, times(1)).execute(eq(canvasHandler),
                                                  commandArgumentCaptor.capture());
 
@@ -339,14 +337,43 @@ public class LocationControlImplTest {
         assertEquals(new Point2D(40d, 50d), updateElementPositionCommand.getLocation());
     }
 
+    @Test
+    public void testHandleKeys() {
+        tested.init(canvasHandler);
+        tested.register(element);
+
+        when (canvasHandler.getGraphIndex().getNode(any())).thenReturn(element);
+
+        tested.getSelectedIDs().add(element.getUUID());
+        tested.handleArrowKeys(KeyboardEvent.Key.ARROW_DOWN);
+
+        verify(commandManager, atLeastOnce()).execute(any(), any());
+    }
+
+    @Test
+    public void testEnsureDragConstraints() throws Exception {
+        tested.init(canvasHandler);
+        Bounds bounds = Bounds.create(0d, 0d, 600d, 600d);
+        when(canvasPanel.getLocationConstraints()).thenReturn(bounds);
+        tested.register(element);
+        verify(shapeView, times(1)).setDragBounds(eq(bounds));
+    }
+
     @Test
     @SuppressWarnings("unchecked")
     public void testDeregister() {
         tested.init(canvasHandler);
         tested.register(element);
         tested.deregister(element);
-        verify(shapeEventHandler,
-               times(1)).removeHandler(any(ViewHandler.class));
+        verify(shapeEventHandler, atLeastOnce()).removeHandler(Mockito.<ViewHandler>any());
         assertFalse(tested.isRegistered(element));
     }
+
+    @Test
+    public void testDestroy() {
+        tested.init(canvasHandler);
+        tested.destroy();
+        verify(wiresManager,
+               atLeastOnce()).setLocationAcceptor(eq(ILocationAcceptor.ALL));
+    }
 }
\ No newline at end of file
