@@ -19,31 +19,36 @@ package org.kie.workbench.common.stunner.core.client.components.toolbox.actions;
 import java.util.Collections;
 import java.util.Iterator;
 import java.util.Optional;
-import java.util.function.Consumer;
+import java.util.function.Predicate;
+import java.util.stream.Collectors;
+import java.util.stream.Stream;
 
 import com.google.gwtmockito.GwtMockitoTestRunner;
+import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
+import org.kie.workbench.common.stunner.core.client.ManagedInstanceStub;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
 import org.kie.workbench.common.stunner.core.client.components.toolbox.Toolbox;
-import org.kie.workbench.common.stunner.core.definition.shape.Glyph;
 import org.kie.workbench.common.stunner.core.diagram.Diagram;
 import org.kie.workbench.common.stunner.core.diagram.Metadata;
 import org.kie.workbench.common.stunner.core.graph.Edge;
 import org.kie.workbench.common.stunner.core.graph.Graph;
 import org.kie.workbench.common.stunner.core.graph.Node;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
-import org.kie.workbench.common.stunner.core.lookup.util.CommonLookups;
+import org.kie.workbench.common.stunner.core.lookup.domain.CommonDomainLookups;
+import org.kie.workbench.common.stunner.core.profile.DomainProfileManager;
 import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
 import org.mockito.Mock;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertTrue;
-import static org.mockito.Matchers.eq;
+import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.any;
-import static org.mockito.Mockito.anyInt;
 import static org.mockito.Mockito.anyString;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
@@ -53,23 +58,34 @@ public class FlowActionsToolboxFactoryTest {
 
     private static final String DS_ID = "defSetId1";
     private static final String EDGE_ID = "edgeId1";
+    private static final String EDGE_ID2 = "edgeId2";
     private static final String NODE_ID = "nodeId1";
+    private static final String NODE_ID2 = "nodeId2";
     private static final String E_UUID = "e1";
 
     @Mock
     private DefinitionUtils definitionUtils;
 
     @Mock
-    private CommonLookups commonLookups;
+    private DomainProfileManager profileManager;
 
     @Mock
-    private CreateConnectorAction createConnectorAction;
+    private ToolboxDomainLookups toolboxLookups;
 
     @Mock
-    private CreateNodeAction createNodeAction;
+    private CommonDomainLookups domainLookups;
+
+    @Mock
+    private CreateConnectorToolboxAction createConnectorAction;
+    private ManagedInstance<CreateConnectorToolboxAction> createConnectorActions;
+
+    @Mock
+    private CreateNodeToolboxAction createNodeAction;
+    private ManagedInstance<CreateNodeToolboxAction> createNodeActions;
 
     @Mock
     private ActionsToolboxView view;
+    private ManagedInstance<ActionsToolboxView> views;
 
     @Mock
     private AbstractCanvasHandler canvasHandler;
@@ -94,62 +110,101 @@ public class FlowActionsToolboxFactoryTest {
         when(createConnectorAction.setEdgeId(anyString())).thenReturn(createConnectorAction);
         when(createNodeAction.setEdgeId(anyString())).thenReturn(createNodeAction);
         when(createNodeAction.setNodeId(anyString())).thenReturn(createNodeAction);
+        createConnectorActions = spy(new ManagedInstanceStub<>(createConnectorAction));
+        createNodeActions = spy(new ManagedInstanceStub<>(createNodeAction));
+        views = spy(new ManagedInstanceStub<>(view));
         when(canvasHandler.getDiagram()).thenReturn(diagram);
         when(diagram.getGraph()).thenReturn(graph);
         when(diagram.getMetadata()).thenReturn(metadata);
         when(metadata.getDefinitionSetId()).thenReturn(DS_ID);
         when(element.getUUID()).thenReturn(E_UUID);
         when(element.asNode()).thenReturn(element);
-        when(commonLookups.getAllowedConnectors(eq(DS_ID),
-                                                eq(element),
-                                                anyInt(),
-                                                anyInt()))
-                .thenReturn(Collections.singleton(EDGE_ID));
-        when(definitionUtils.getDefaultConnectorId(eq(DS_ID)))
-                .thenReturn(EDGE_ID);
-        when(commonLookups.getAllowedMorphDefaultDefinitions(eq(DS_ID),
-                                                             eq(graph),
-                                                             eq(element),
-                                                             eq(EDGE_ID),
-                                                             anyInt(),
-                                                             anyInt()))
+        when(toolboxLookups.get(anyString())).thenReturn(domainLookups);
+        when(domainLookups.lookupTargetConnectors(eq(element)))
+                .thenReturn(Stream.of(EDGE_ID, EDGE_ID2).collect(Collectors.toSet()));
+        when(domainLookups.lookupTargetNodes(eq(graph),
+                                             eq(element),
+                                             eq(EDGE_ID),
+                                             any(Predicate.class)))
                 .thenReturn(Collections.singleton(NODE_ID));
+        when(domainLookups.lookupTargetNodes(eq(graph),
+                                             eq(element),
+                                             eq(EDGE_ID2),
+                                             any(Predicate.class)))
+                .thenReturn(Collections.singleton(NODE_ID2));
+
+        when(domainLookups.lookupMorphBaseDefinitions(Stream.of(NODE_ID).collect(Collectors.toSet())))
+                .thenReturn(Collections.singleton(NODE_ID));
+
+        when(domainLookups.lookupMorphBaseDefinitions(Stream.of(NODE_ID2).collect(Collectors.toSet())))
+                .thenReturn(Collections.singleton(NODE_ID2));
+
         this.tested = new FlowActionsToolboxFactory(definitionUtils,
-                                                    commonLookups,
-                                                    () -> createConnectorAction,
-                                                    () -> createNodeAction,
-                                                    () -> view);
+                                                    toolboxLookups,
+                                                    profileManager,
+                                                    createConnectorActions,
+                                                    createNodeActions,
+                                                    views);
     }
 
     @Test
     @SuppressWarnings("unchecked")
     public void testBuildToolbox() {
+        Predicate<String> profileFilter = mock(Predicate.class);
+        when(profileManager.isDefinitionIdAllowed(eq(metadata))).thenReturn(profileFilter);
         final Optional<Toolbox<?>> toolbox =
                 tested.build(canvasHandler,
                              element);
+        verify(profileManager, times(2)).isDefinitionIdAllowed(eq(metadata));
+        verify(domainLookups, times(1)).lookupTargetNodes(eq(graph),
+                                                          eq(element),
+                                                          eq(EDGE_ID),
+                                                          eq(profileFilter));
+        verify(domainLookups, times(1)).lookupTargetNodes(eq(graph),
+                                                          eq(element),
+                                                          eq(EDGE_ID2),
+                                                          eq(profileFilter));
         assertTrue(toolbox.isPresent());
         assertTrue(toolbox.get() instanceof ActionsToolbox);
         final ActionsToolbox actionsToolbox = (ActionsToolbox) toolbox.get();
         assertEquals(E_UUID,
                      actionsToolbox.getElementUUID());
-        assertEquals(2,
+        assertEquals(4,
                      actionsToolbox.size());
         final Iterator actionIt = actionsToolbox.iterator();
+        assertEquals(createConnectorAction,
+                     actionIt.next());
         assertEquals(createConnectorAction,
                      actionIt.next());
         assertEquals(createNodeAction,
                      actionIt.next());
+        assertEquals(createNodeAction,
+                     actionIt.next());
+
         verify(createConnectorAction,
                times(1)).setEdgeId(eq(EDGE_ID));
+        verify(createConnectorAction,
+               times(1)).setEdgeId(eq(EDGE_ID2));
+
         verify(createNodeAction,
                times(1)).setEdgeId(eq(EDGE_ID));
+        verify(createNodeAction,
+               times(1)).setEdgeId(eq(EDGE_ID2));
+
         verify(createNodeAction,
                times(1)).setNodeId(eq(NODE_ID));
+        verify(createNodeAction,
+               times(1)).setNodeId(eq(NODE_ID2));
+
         verify(view,
                times(1)).init(eq(actionsToolbox));
-        verify(view,
-               times(2)).addButton(any(Glyph.class),
-                                   anyString(),
-                                   any(Consumer.class));
+    }
+
+    @Test
+    public void testDestroy() {
+        tested.destroy();
+        verify(createConnectorActions, times(1)).destroyAll();
+        verify(createNodeActions, times(1)).destroyAll();
+        verify(views, times(1)).destroyAll();
     }
 }
