@@ -20,14 +20,14 @@ import javax.inject.Inject;
 
 import org.gwtbootstrap3.client.ui.constants.IconType;
 import org.jboss.errai.ui.client.local.spi.TranslationService;
-import org.kie.workbench.common.stunner.kogito.client.resources.i18n.KogitoClientMessages;
-import org.kie.workbench.common.stunner.kogito.client.screens.DiagramEditorPropertiesScreen;
+import org.kie.workbench.common.stunner.forms.client.resources.i18n.FormsClientConstants;
+import org.kie.workbench.common.stunner.forms.client.screens.DiagramEditorPropertiesScreen;
 import org.uberfire.client.workbench.docks.UberfireDocks;
 
 @ApplicationScoped
 public class DiagramEditorPropertiesDock extends BaseDiagramEditorDock {
 
-    public DiagramEditorPropertiesDock() {
+    protected DiagramEditorPropertiesDock() {
         // CDI proxy
         this(null, null);
     }
@@ -50,6 +50,6 @@ public class DiagramEditorPropertiesDock extends BaseDiagramEditorDock {
 
     @Override
     protected final String getLabelKey() {
-        return KogitoClientMessages.PROPERTIES_DOCK_TITLE;
+        return FormsClientConstants.FormsPropertiesDockTitle;
     }
 }
