@@ -16,8 +16,6 @@
 
 package org.kie.workbench.common.stunner.bpmn.definition;
 
-import javax.validation.Valid;
-
 import org.jboss.errai.common.client.api.annotations.MapsTo;
 import org.jboss.errai.common.client.api.annotations.Portable;
 import org.jboss.errai.databinding.client.api.Bindable;
@@ -27,7 +25,6 @@ import org.kie.workbench.common.forms.adf.definitions.annotations.FormField;
 import org.kie.workbench.common.forms.adf.definitions.settings.FieldPolicy;
 import org.kie.workbench.common.stunner.bpmn.definition.property.background.BackgroundSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.dataio.DataIOModel;
-import org.kie.workbench.common.stunner.bpmn.definition.property.dataio.DataIOSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.RectangleDimensionsSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.font.FontSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.general.Documentation;
@@ -38,9 +35,8 @@ import org.kie.workbench.common.stunner.bpmn.definition.property.simulation.Simu
 import org.kie.workbench.common.stunner.bpmn.definition.property.task.TaskType;
 import org.kie.workbench.common.stunner.bpmn.definition.property.task.TaskTypes;
 import org.kie.workbench.common.stunner.core.definition.annotation.Definition;
-import org.kie.workbench.common.stunner.core.definition.annotation.PropertySet;
+import org.kie.workbench.common.stunner.core.definition.annotation.Property;
 import org.kie.workbench.common.stunner.core.definition.annotation.morph.Morph;
-import org.kie.workbench.common.stunner.core.factory.graph.NodeFactory;
 import org.kie.workbench.common.stunner.core.rule.annotation.CanDock;
 import org.kie.workbench.common.stunner.core.util.HashUtil;
 
@@ -49,7 +45,7 @@ import static org.kie.workbench.common.forms.adf.engine.shared.formGeneration.pr
 
 @Portable
 @Bindable
-@Definition(graphFactory = NodeFactory.class)
+@Definition
 @CanDock(roles = {"IntermediateEventOnActivityBoundary"})
 @Morph(base = BaseTask.class)
 @FormDefinition(
@@ -59,20 +55,16 @@ import static org.kie.workbench.common.forms.adf.engine.shared.formGeneration.pr
 )
 public class GenericServiceTask extends BaseTask implements DataIOModel {
 
-    @PropertySet
+    @Property
     @FormField(
             afterElement = "general"
     )
     protected GenericServiceTaskExecutionSet executionSet;
 
-    @Valid
-    protected DataIOSet dataIOSet;
-
     public GenericServiceTask() {
         this(new TaskGeneralSet(new Name("Service Task"),
                                 new Documentation("")),
              new GenericServiceTaskExecutionSet(),
-             new DataIOSet(),
              new BackgroundSet(),
              new FontSet(),
              new RectangleDimensionsSet(),
@@ -82,7 +74,6 @@ public class GenericServiceTask extends BaseTask implements DataIOModel {
 
     public GenericServiceTask(final @MapsTo("general") TaskGeneralSet general,
                               final @MapsTo("executionSet") GenericServiceTaskExecutionSet executionSet,
-                              final @MapsTo("dataIOSet") DataIOSet dataIOSet,
                               final @MapsTo("backgroundSet") BackgroundSet backgroundSet,
                               final @MapsTo("fontSet") FontSet fontSet,
                               final @MapsTo("dimensionsSet") RectangleDimensionsSet dimensionsSet,
@@ -95,7 +86,6 @@ public class GenericServiceTask extends BaseTask implements DataIOModel {
               simulationSet,
               taskType);
         this.executionSet = executionSet;
-        this.dataIOSet = dataIOSet;
     }
 
     public GenericServiceTaskExecutionSet getExecutionSet() {
@@ -126,14 +116,9 @@ public class GenericServiceTask extends BaseTask implements DataIOModel {
         return false;
     }
 
-    public void setDataIOSet(final DataIOSet dataIOSet) {
-        this.dataIOSet = dataIOSet;
-    }
-
     @Override
     public int hashCode() {
         return HashUtil.combineHashCodes(super.hashCode(),
-                                         dataIOSet.hashCode(),
                                          executionSet.hashCode());
     }
 
@@ -142,7 +127,6 @@ public class GenericServiceTask extends BaseTask implements DataIOModel {
         if (o instanceof GenericServiceTask) {
             GenericServiceTask other = (GenericServiceTask) o;
             return super.equals(other) &&
-                    dataIOSet.equals(other.dataIOSet) &&
                     executionSet.equals(other.executionSet);
         }
         return false;
