@@ -1,5 +1,5 @@
 /*
- * Copyright 2018 Red Hat, Inc. and/or its affiliates.
+ * Copyright 2019 Red Hat, Inc. and/or its affiliates.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -23,8 +23,7 @@ import org.kie.workbench.common.stunner.core.diagram.Diagram;
 import org.kie.workbench.common.stunner.core.diagram.Metadata;
 import org.kie.workbench.common.stunner.core.graph.Graph;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
+import static org.assertj.core.api.Assertions.assertThat;
 
 public class ThrowingIntermediateSignalEventTest extends ThrowingIntermediateEventTest<IntermediateSignalEventThrowing> {
 
@@ -40,15 +39,15 @@ public class ThrowingIntermediateSignalEventTest extends ThrowingIntermediateEve
     private static final String FILLED_SUBPROCESS_LEVEL_PROJECT_SCOPE_ID = "1CFE1286-A741-4199-9589-3C5E818223AC";
     private static final String FILLED_SUBPROCESS_LEVEL_EVENT_EXTERNAL_SCOPE_ID = "35E9A791-ED38-4DDD-9853-6214E528A2E7";
 
-    private static final String EMPTY_WITH_INCOME_TOP_LEVEL_EVENT_ID = "4ABCB559-F522-47E7-84A8-9D9F9189CDCA";
-    private static final String FILLED_WITH_INCOME_TOP_LEVEL_EVENT_PROCESS_INSTANCE_SCOPE_ID = "0F011259-FA4F-458A-A9AB-A6C5C18257CE";
-    private static final String FILLED_WITH_INCOME_TOP_LEVEL_PROJECT_SCOPE_ID = "CCDF61B4-2795-4DFD-95EC-667D56E110DB";
-    private static final String FILLED_WITH_INCOME_TOP_LEVEL_EVENT_EXTERNAL_SCOPE_ID = "3E469F07-B684-49D7-B97A-60DD22F12E01";
+    private static final String EMPTY_WITH_EDGES_TOP_LEVEL_EVENT_ID = "4ABCB559-F522-47E7-84A8-9D9F9189CDCA";
+    private static final String FILLED_WITH_EDGES_TOP_LEVEL_EVENT_PROCESS_INSTANCE_SCOPE_ID = "0F011259-FA4F-458A-A9AB-A6C5C18257CE";
+    private static final String FILLED_WITH_EDGES_TOP_LEVEL_PROJECT_SCOPE_ID = "CCDF61B4-2795-4DFD-95EC-667D56E110DB";
+    private static final String FILLED_WITH_EDGES_TOP_LEVEL_EVENT_EXTERNAL_SCOPE_ID = "3E469F07-B684-49D7-B97A-60DD22F12E01";
 
-    private static final String EMPTY_WITH_INCOME_SUBPROCESS_LEVEL_EVENT_ID = "E7566B4F-FA5A-447F-963D-6C41C5C5A871";
-    private static final String FILLED_WITH_INCOME_SUBPROCESS_LEVEL_PROCESS_INSTANCE_SCOPE_ID = "EFD41F08-FED7-43E9-9393-C356D7EFF7BA";
-    private static final String FILLED_WITH_INCOME_SUBPROCESS_LEVEL_PROJECT_SCOPE_ID = "11FD55C3-5370-4F15-8FC2-CCDC657C2D39";
-    private static final String FILLED_WITH_INCOME_SUBPROCESS_LEVEL_EVENT_EXTERNAL_SCOPE_ID = "84FC0F13-BD60-4E18-848C-6DD63E1D93AD";
+    private static final String EMPTY_WITH_EDGES_SUBPROCESS_LEVEL_EVENT_ID = "E7566B4F-FA5A-447F-963D-6C41C5C5A871";
+    private static final String FILLED_WITH_EDGES_SUBPROCESS_LEVEL_PROCESS_INSTANCE_SCOPE_ID = "EFD41F08-FED7-43E9-9393-C356D7EFF7BA";
+    private static final String FILLED_WITH_EDGES_SUBPROCESS_LEVEL_PROJECT_SCOPE_ID = "11FD55C3-5370-4F15-8FC2-CCDC657C2D39";
+    private static final String FILLED_WITH_EDGES_SUBPROCESS_LEVEL_EVENT_EXTERNAL_SCOPE_ID = "84FC0F13-BD60-4E18-848C-6DD63E1D93AD";
 
     private static final int AMOUNT_OF_NODES_IN_DIAGRAM = 43;
 
@@ -57,6 +56,9 @@ public class ThrowingIntermediateSignalEventTest extends ThrowingIntermediateEve
     private static final String EVENT_SIGNAL_SCOPE_PROJECT = "project";
     private static final String EVENT_SIGNAL_SCOPE_EXTERNAL = "external";
 
+    public ThrowingIntermediateSignalEventTest() throws Exception {
+    }
+
     @Test
     @Override
     public void testUnmarshallTopLevelEventFilledProperties() throws Exception {
@@ -75,26 +77,26 @@ public class ThrowingIntermediateSignalEventTest extends ThrowingIntermediateEve
         final String EVENT_REF_EXTERNAL_SCOPE = "signal03";
         final String EVENT_DATA_INPUT_EXTERNAL_SCOPE = "signal03:String||||[din]GlobalVar->signal03";
 
-        Diagram<Graph, Metadata> diagram = unmarshall(marshaller, BPMN_THROWING_INTERMEDIATE_EVENT_FILE_PATH);
+        Diagram<Graph, Metadata> diagram = getDiagram();
         assertDiagram(diagram, AMOUNT_OF_NODES_IN_DIAGRAM);
 
         IntermediateSignalEventThrowing filledTopEventProcessInstance = getThrowingIntermediateNodeById(diagram,
                                                                                                         FILLED_TOP_LEVEL_EVENT_PROCESS_INSTANCE_SCOPE_ID,
-                                                                                                        HAS_NO_INCOME_EDGE);
+                                                                                                        HAS_NO_INCOME_EDGE, ZERO_OUTGOING_EDGES);
         assertGeneralSet(filledTopEventProcessInstance.getGeneral(), EVENT_NAME_PROCESS_INSTANCE_SCOPE, EVENT_DOCUMENTATION_PROCESS_INSTANCE_SCOPE);
         assertSignalEventExecutionSet(filledTopEventProcessInstance.getExecutionSet(), EVENT_REF_PROCESS_INSTANCE_SCOPE, EVENT_SIGNAL_SCOPE_PROCESS_INSTANCE);
         assertDataIOSet(filledTopEventProcessInstance.getDataIOSet(), EVENT_DATA_INPUT_PROCESS_INSTANCE_SCOPE);
 
         IntermediateSignalEventThrowing filledTopEventProject = getThrowingIntermediateNodeById(diagram,
                                                                                                 FILLED_TOP_LEVEL_EVENT_PROJECT_SCOPE_ID,
-                                                                                                HAS_NO_INCOME_EDGE);
+                                                                                                HAS_NO_INCOME_EDGE, ZERO_OUTGOING_EDGES);
         assertGeneralSet(filledTopEventProject.getGeneral(), EVENT_NAME_PROJECT_SCOPE, EVENT_DOCUMENTATION_PROJECT_SCOPE);
         assertSignalEventExecutionSet(filledTopEventProject.getExecutionSet(), EVENT_REF_PROJECT_SCOPE, EVENT_SIGNAL_SCOPE_PROJECT);
         assertDataIOSet(filledTopEventProject.getDataIOSet(), EVENT_DATA_INPUT_PROJECT_SCOPE);
 
         IntermediateSignalEventThrowing filledTopEventExternal = getThrowingIntermediateNodeById(diagram,
                                                                                                  FILLED_TOP_LEVEL_EVENT_EXTERNAL_SCOPE_ID,
-                                                                                                 HAS_NO_INCOME_EDGE);
+                                                                                                 HAS_NO_INCOME_EDGE, ZERO_OUTGOING_EDGES);
         assertGeneralSet(filledTopEventExternal.getGeneral(), EVENT_NAME_EXTERNAL_SCOPE, EVENT_DOCUMENTATION_EXTERNAL_SCOPE);
         assertSignalEventExecutionSet(filledTopEventExternal.getExecutionSet(), EVENT_REF_EXTERNAL_SCOPE, EVENT_SIGNAL_SCOPE_EXTERNAL);
         assertDataIOSet(filledTopEventExternal.getDataIOSet(), EVENT_DATA_INPUT_EXTERNAL_SCOPE);
@@ -103,12 +105,12 @@ public class ThrowingIntermediateSignalEventTest extends ThrowingIntermediateEve
     @Test
     @Override
     public void testUnmarshallTopLevelEmptyEventProperties() throws Exception {
-        Diagram<Graph, Metadata> diagram = unmarshall(marshaller, BPMN_THROWING_INTERMEDIATE_EVENT_FILE_PATH);
+        Diagram<Graph, Metadata> diagram = getDiagram();
         assertDiagram(diagram, AMOUNT_OF_NODES_IN_DIAGRAM);
 
         IntermediateSignalEventThrowing emptyTopEvent = getThrowingIntermediateNodeById(diagram,
                                                                                         EMPTY_TOP_LEVEL_EVENT_ID,
-                                                                                        HAS_NO_INCOME_EDGE);
+                                                                                        HAS_NO_INCOME_EDGE, ZERO_OUTGOING_EDGES);
         assertGeneralSet(emptyTopEvent.getGeneral(), EMPTY_VALUE, EMPTY_VALUE);
         assertSignalEventExecutionSet(emptyTopEvent.getExecutionSet(), EMPTY_VALUE, EVENT_SIGNAL_SCOPE_DEFAULT);
         assertDataIOSet(emptyTopEvent.getDataIOSet(), EMPTY_VALUE);
@@ -132,26 +134,26 @@ public class ThrowingIntermediateSignalEventTest extends ThrowingIntermediateEve
         final String EVENT_REF_EXTERNAL_SCOPE = "signal09";
         final String EVENT_DATA_INPUT_EXTERNAL_SCOPE = "signal09:String||||[din]GlobalVar->signal09";
 
-        Diagram<Graph, Metadata> diagram = unmarshall(marshaller, BPMN_THROWING_INTERMEDIATE_EVENT_FILE_PATH);
+        Diagram<Graph, Metadata> diagram = getDiagram();
         assertDiagram(diagram, AMOUNT_OF_NODES_IN_DIAGRAM);
 
         IntermediateSignalEventThrowing filledSubprocessEventProcessInstance = getThrowingIntermediateNodeById(diagram,
                                                                                                                FILLED_SUBPROCESS_LEVEL_PROCESS_INSTANCE_SCOPE_ID,
-                                                                                                               HAS_NO_INCOME_EDGE);
+                                                                                                               HAS_NO_INCOME_EDGE, ZERO_OUTGOING_EDGES);
         assertGeneralSet(filledSubprocessEventProcessInstance.getGeneral(), EVENT_NAME_PROCESS_INSTANCE_SCOPE, EVENT_DOCUMENTATION_PROCESS_INSTANCE_SCOPE);
         assertSignalEventExecutionSet(filledSubprocessEventProcessInstance.getExecutionSet(), EVENT_REF_PROCESS_INSTANCE_SCOPE, EVENT_SIGNAL_SCOPE_PROCESS_INSTANCE);
         assertDataIOSet(filledSubprocessEventProcessInstance.getDataIOSet(), EVENT_DATA_INPUT_PROCESS_INSTANCE_SCOPE);
 
         IntermediateSignalEventThrowing filledSubprocessEventProject = getThrowingIntermediateNodeById(diagram,
                                                                                                        FILLED_SUBPROCESS_LEVEL_PROJECT_SCOPE_ID,
-                                                                                                       HAS_NO_INCOME_EDGE);
+                                                                                                       HAS_NO_INCOME_EDGE, ZERO_OUTGOING_EDGES);
         assertGeneralSet(filledSubprocessEventProject.getGeneral(), EVENT_NAME_PROJECT_SCOPE, EVENT_DOCUMENTATION_PROJECT_SCOPE);
         assertSignalEventExecutionSet(filledSubprocessEventProject.getExecutionSet(), EVENT_REF_PROJECT_SCOPE, EVENT_SIGNAL_SCOPE_PROJECT);
         assertDataIOSet(filledSubprocessEventProject.getDataIOSet(), EVENT_DATA_INPUT_PROJECT_SCOPE);
 
         IntermediateSignalEventThrowing filledSubprocessEventExternal = getThrowingIntermediateNodeById(diagram,
                                                                                                         FILLED_SUBPROCESS_LEVEL_EVENT_EXTERNAL_SCOPE_ID,
-                                                                                                        HAS_NO_INCOME_EDGE);
+                                                                                                        HAS_NO_INCOME_EDGE, ZERO_OUTGOING_EDGES);
         assertGeneralSet(filledSubprocessEventExternal.getGeneral(), EVENT_NAME_EXTERNAL_SCOPE, EVENT_DOCUMENTATION_EXTERNAL_SCOPE);
         assertSignalEventExecutionSet(filledSubprocessEventExternal.getExecutionSet(), EVENT_REF_EXTERNAL_SCOPE, EVENT_SIGNAL_SCOPE_EXTERNAL);
         assertDataIOSet(filledSubprocessEventExternal.getDataIOSet(), EVENT_DATA_INPUT_EXTERNAL_SCOPE);
@@ -160,12 +162,12 @@ public class ThrowingIntermediateSignalEventTest extends ThrowingIntermediateEve
     @Test
     @Override
     public void testUnmarshallSubprocessLevelEventEmptyProperties() throws Exception {
-        Diagram<Graph, Metadata> diagram = unmarshall(marshaller, BPMN_THROWING_INTERMEDIATE_EVENT_FILE_PATH);
+        Diagram<Graph, Metadata> diagram = getDiagram();
         assertDiagram(diagram, AMOUNT_OF_NODES_IN_DIAGRAM);
 
         IntermediateSignalEventThrowing emptySubprocessEvent = getThrowingIntermediateNodeById(diagram,
                                                                                                EMPTY_SUBPROCESS_LEVEL_EVENT_ID,
-                                                                                               HAS_NO_INCOME_EDGE);
+                                                                                               HAS_NO_INCOME_EDGE, ZERO_OUTGOING_EDGES);
         assertGeneralSet(emptySubprocessEvent.getGeneral(), EMPTY_VALUE, EMPTY_VALUE);
         assertSignalEventExecutionSet(emptySubprocessEvent.getExecutionSet(), EMPTY_VALUE, EVENT_SIGNAL_SCOPE_DEFAULT);
         assertDataIOSet(emptySubprocessEvent.getDataIOSet(), EMPTY_VALUE);
@@ -173,7 +175,7 @@ public class ThrowingIntermediateSignalEventTest extends ThrowingIntermediateEve
 
     @Test
     @Override
-    public void testUnmarshallTopLevelEventWithIncomeFilledProperties() throws Exception {
+    public void testUnmarshallTopLevelEventWithEdgesFilledProperties() {
         final String EVENT_NAME_PROCESS_INSTANCE_SCOPE = "signal04 ~!@#$%^&*()_+`-={}|[]\\:\";'<>?,./";
         final String EVENT_DOCUMENTATION_PROCESS_INSTANCE_SCOPE = "signal04 doc\n ~!@#$%^&*()_+`1234567890-={}|[]\\:\";'<>?,./";
         final String EVENT_REF_PROCESS_INSTANCE_SCOPE = "signal04";
@@ -189,26 +191,26 @@ public class ThrowingIntermediateSignalEventTest extends ThrowingIntermediateEve
         final String EVENT_REF_EXTERNAL_SCOPE = "signal06";
         final String EVENT_DATA_INPUT_EXTERNAL_SCOPE = "signal06:String||||[din]GlobalVar->signal06";
 
-        Diagram<Graph, Metadata> diagram = unmarshall(marshaller, BPMN_THROWING_INTERMEDIATE_EVENT_FILE_PATH);
+        Diagram<Graph, Metadata> diagram = getDiagram();
         assertDiagram(diagram, AMOUNT_OF_NODES_IN_DIAGRAM);
 
         IntermediateSignalEventThrowing filledTopEventProcessInstance = getThrowingIntermediateNodeById(diagram,
-                                                                                                        FILLED_WITH_INCOME_TOP_LEVEL_EVENT_PROCESS_INSTANCE_SCOPE_ID,
-                                                                                                        HAS_INCOME_EDGE);
+                                                                                                        FILLED_WITH_EDGES_TOP_LEVEL_EVENT_PROCESS_INSTANCE_SCOPE_ID,
+                                                                                                        HAS_INCOME_EDGE, TWO_OUTGOING_EDGES);
         assertGeneralSet(filledTopEventProcessInstance.getGeneral(), EVENT_NAME_PROCESS_INSTANCE_SCOPE, EVENT_DOCUMENTATION_PROCESS_INSTANCE_SCOPE);
         assertSignalEventExecutionSet(filledTopEventProcessInstance.getExecutionSet(), EVENT_REF_PROCESS_INSTANCE_SCOPE, EVENT_SIGNAL_SCOPE_PROCESS_INSTANCE);
         assertDataIOSet(filledTopEventProcessInstance.getDataIOSet(), EVENT_DATA_INPUT_PROCESS_INSTANCE_SCOPE);
 
         IntermediateSignalEventThrowing filledTopEventProject = getThrowingIntermediateNodeById(diagram,
-                                                                                                FILLED_WITH_INCOME_TOP_LEVEL_PROJECT_SCOPE_ID,
-                                                                                                HAS_INCOME_EDGE);
+                                                                                                FILLED_WITH_EDGES_TOP_LEVEL_PROJECT_SCOPE_ID,
+                                                                                                HAS_INCOME_EDGE, TWO_OUTGOING_EDGES);
         assertGeneralSet(filledTopEventProject.getGeneral(), EVENT_NAME_PROJECT_SCOPE, EVENT_DOCUMENTATION_PROJECT_SCOPE);
         assertSignalEventExecutionSet(filledTopEventProject.getExecutionSet(), EVENT_REF_PROJECT_SCOPE, EVENT_SIGNAL_SCOPE_PROJECT);
         assertDataIOSet(filledTopEventProject.getDataIOSet(), EVENT_DATA_INPUT_PROJECT_SCOPE);
 
         IntermediateSignalEventThrowing filledTopEventExternal = getThrowingIntermediateNodeById(diagram,
-                                                                                                 FILLED_WITH_INCOME_TOP_LEVEL_EVENT_EXTERNAL_SCOPE_ID,
-                                                                                                 HAS_INCOME_EDGE);
+                                                                                                 FILLED_WITH_EDGES_TOP_LEVEL_EVENT_EXTERNAL_SCOPE_ID,
+                                                                                                 HAS_INCOME_EDGE, TWO_OUTGOING_EDGES);
         assertGeneralSet(filledTopEventExternal.getGeneral(), EVENT_NAME_EXTERNAL_SCOPE, EVENT_DOCUMENTATION_EXTERNAL_SCOPE);
         assertSignalEventExecutionSet(filledTopEventExternal.getExecutionSet(), EVENT_REF_EXTERNAL_SCOPE, EVENT_SIGNAL_SCOPE_EXTERNAL);
         assertDataIOSet(filledTopEventExternal.getDataIOSet(), EVENT_DATA_INPUT_EXTERNAL_SCOPE);
@@ -216,13 +218,13 @@ public class ThrowingIntermediateSignalEventTest extends ThrowingIntermediateEve
 
     @Test
     @Override
-    public void testUnmarshallTopLevelEventWithIncomeEmptyProperties() throws Exception {
-        Diagram<Graph, Metadata> diagram = unmarshall(marshaller, BPMN_THROWING_INTERMEDIATE_EVENT_FILE_PATH);
+    public void testUnmarshallTopLevelEventWithEdgesEmptyProperties() {
+        Diagram<Graph, Metadata> diagram = getDiagram();
         assertDiagram(diagram, AMOUNT_OF_NODES_IN_DIAGRAM);
 
         IntermediateSignalEventThrowing emptyEvent = getThrowingIntermediateNodeById(diagram,
-                                                                                     EMPTY_WITH_INCOME_TOP_LEVEL_EVENT_ID,
-                                                                                     HAS_INCOME_EDGE);
+                                                                                     EMPTY_WITH_EDGES_TOP_LEVEL_EVENT_ID,
+                                                                                     HAS_INCOME_EDGE, TWO_OUTGOING_EDGES);
         assertGeneralSet(emptyEvent.getGeneral(), EMPTY_VALUE, EMPTY_VALUE);
         assertSignalEventExecutionSet(emptyEvent.getExecutionSet(), EMPTY_VALUE, EVENT_SIGNAL_SCOPE_DEFAULT);
         assertDataIOSet(emptyEvent.getDataIOSet(), EMPTY_VALUE);
@@ -230,13 +232,13 @@ public class ThrowingIntermediateSignalEventTest extends ThrowingIntermediateEve
 
     @Test
     @Override
-    public void testUnmarshallSubprocessLevelEventWithIncomeEmptyProperties() throws Exception {
-        Diagram<Graph, Metadata> diagram = unmarshall(marshaller, BPMN_THROWING_INTERMEDIATE_EVENT_FILE_PATH);
+    public void testUnmarshallSubprocessLevelEventWithEdgesEmptyProperties() {
+        Diagram<Graph, Metadata> diagram = getDiagram();
         assertDiagram(diagram, AMOUNT_OF_NODES_IN_DIAGRAM);
 
         IntermediateSignalEventThrowing emptySubprocessEvent = getThrowingIntermediateNodeById(diagram,
-                                                                                               EMPTY_WITH_INCOME_SUBPROCESS_LEVEL_EVENT_ID,
-                                                                                               HAS_INCOME_EDGE);
+                                                                                               EMPTY_WITH_EDGES_SUBPROCESS_LEVEL_EVENT_ID,
+                                                                                               HAS_INCOME_EDGE, TWO_OUTGOING_EDGES);
         assertGeneralSet(emptySubprocessEvent.getGeneral(), EMPTY_VALUE, EMPTY_VALUE);
         assertSignalEventExecutionSet(emptySubprocessEvent.getExecutionSet(), EMPTY_VALUE, EVENT_SIGNAL_SCOPE_DEFAULT);
         assertDataIOSet(emptySubprocessEvent.getDataIOSet(), EMPTY_VALUE);
@@ -244,7 +246,7 @@ public class ThrowingIntermediateSignalEventTest extends ThrowingIntermediateEve
 
     @Test
     @Override
-    public void testUnmarshallSubprocessLevelEventWithIncomeFilledProperties() throws Exception {
+    public void testUnmarshallSubprocessLevelEventWithEdgesFilledProperties() {
         final String EVENT_NAME_PROCESS_INSTANCE_SCOPE = "signal10 ~!@#$%^&*()_+`-={}|[]\\:\";'<>?,./";
         final String EVENT_DOCUMENTATION_PROCESS_INSTANCE_SCOPE = "signal10 doc\n ~!@#$%^&*()_+`1234567890-={}|[]\\:\";'<>?,./";
         final String EVENT_REF_PROCESS_INSTANCE_SCOPE = "signal10";
@@ -260,63 +262,31 @@ public class ThrowingIntermediateSignalEventTest extends ThrowingIntermediateEve
         final String EVENT_REF_EXTERNAL_SCOPE = "signal12";
         final String EVENT_DATA_INPUT_EXTERNAL_SCOPE = "signal12:String||||[din]GlobalVar->signal12";
 
-        Diagram<Graph, Metadata> diagram = unmarshall(marshaller, BPMN_THROWING_INTERMEDIATE_EVENT_FILE_PATH);
+        Diagram<Graph, Metadata> diagram = getDiagram();
         assertDiagram(diagram, AMOUNT_OF_NODES_IN_DIAGRAM);
 
         IntermediateSignalEventThrowing filledSubprocessEventProcessInstance = getThrowingIntermediateNodeById(diagram,
-                                                                                                               FILLED_WITH_INCOME_SUBPROCESS_LEVEL_PROCESS_INSTANCE_SCOPE_ID,
-                                                                                                               HAS_INCOME_EDGE);
+                                                                                                               FILLED_WITH_EDGES_SUBPROCESS_LEVEL_PROCESS_INSTANCE_SCOPE_ID,
+                                                                                                               HAS_INCOME_EDGE, TWO_OUTGOING_EDGES);
         assertGeneralSet(filledSubprocessEventProcessInstance.getGeneral(), EVENT_NAME_PROCESS_INSTANCE_SCOPE, EVENT_DOCUMENTATION_PROCESS_INSTANCE_SCOPE);
         assertSignalEventExecutionSet(filledSubprocessEventProcessInstance.getExecutionSet(), EVENT_REF_PROCESS_INSTANCE_SCOPE, EVENT_SIGNAL_SCOPE_PROCESS_INSTANCE);
         assertDataIOSet(filledSubprocessEventProcessInstance.getDataIOSet(), EVENT_DATA_INPUT_PROCESS_INSTANCE_SCOPE);
 
         IntermediateSignalEventThrowing filledSubprocessEventProject = getThrowingIntermediateNodeById(diagram,
-                                                                                                       FILLED_WITH_INCOME_SUBPROCESS_LEVEL_PROJECT_SCOPE_ID,
-                                                                                                       HAS_INCOME_EDGE);
+                                                                                                       FILLED_WITH_EDGES_SUBPROCESS_LEVEL_PROJECT_SCOPE_ID,
+                                                                                                       HAS_INCOME_EDGE, TWO_OUTGOING_EDGES);
         assertGeneralSet(filledSubprocessEventProject.getGeneral(), EVENT_NAME_PROJECT_SCOPE, EVENT_DOCUMENTATION_PROJECT_SCOPE);
         assertSignalEventExecutionSet(filledSubprocessEventProject.getExecutionSet(), EVENT_REF_PROJECT_SCOPE, EVENT_SIGNAL_SCOPE_PROJECT);
         assertDataIOSet(filledSubprocessEventProject.getDataIOSet(), EVENT_DATA_INPUT_PROJECT_SCOPE);
 
         IntermediateSignalEventThrowing filledSubprocessEventExternal = getThrowingIntermediateNodeById(diagram,
-                                                                                                        FILLED_WITH_INCOME_SUBPROCESS_LEVEL_EVENT_EXTERNAL_SCOPE_ID,
-                                                                                                        HAS_INCOME_EDGE);
+                                                                                                        FILLED_WITH_EDGES_SUBPROCESS_LEVEL_EVENT_EXTERNAL_SCOPE_ID,
+                                                                                                        HAS_INCOME_EDGE, TWO_OUTGOING_EDGES);
         assertGeneralSet(filledSubprocessEventExternal.getGeneral(), EVENT_NAME_EXTERNAL_SCOPE, EVENT_DOCUMENTATION_EXTERNAL_SCOPE);
         assertSignalEventExecutionSet(filledSubprocessEventExternal.getExecutionSet(), EVENT_REF_EXTERNAL_SCOPE, EVENT_SIGNAL_SCOPE_EXTERNAL);
         assertDataIOSet(filledSubprocessEventExternal.getDataIOSet(), EVENT_DATA_INPUT_EXTERNAL_SCOPE);
     }
 
-    @Test
-    @Override
-    public void testMarshallTopLevelEventFilledProperties() throws Exception {
-        checkEventMarshalling(FILLED_TOP_LEVEL_EVENT_PROCESS_INSTANCE_SCOPE_ID, HAS_NO_INCOME_EDGE);
-        checkEventMarshalling(FILLED_TOP_LEVEL_EVENT_PROJECT_SCOPE_ID, HAS_NO_INCOME_EDGE);
-        checkEventMarshalling(FILLED_TOP_LEVEL_EVENT_EXTERNAL_SCOPE_ID, HAS_NO_INCOME_EDGE);
-    }
-
-    @Test
-    @Override
-    public void testMarshallSubprocessLevelEventFilledProperties() throws Exception {
-        checkEventMarshalling(FILLED_SUBPROCESS_LEVEL_PROCESS_INSTANCE_SCOPE_ID, HAS_NO_INCOME_EDGE);
-        checkEventMarshalling(FILLED_SUBPROCESS_LEVEL_PROJECT_SCOPE_ID, HAS_NO_INCOME_EDGE);
-        checkEventMarshalling(FILLED_SUBPROCESS_LEVEL_EVENT_EXTERNAL_SCOPE_ID, HAS_NO_INCOME_EDGE);
-    }
-
-    @Test
-    @Override
-    public void testMarshallTopLevelEventWithIncomeFilledProperties() throws Exception {
-        checkEventMarshalling(FILLED_WITH_INCOME_TOP_LEVEL_EVENT_PROCESS_INSTANCE_SCOPE_ID, HAS_INCOME_EDGE);
-        checkEventMarshalling(FILLED_WITH_INCOME_TOP_LEVEL_PROJECT_SCOPE_ID, HAS_INCOME_EDGE);
-        checkEventMarshalling(FILLED_WITH_INCOME_TOP_LEVEL_EVENT_EXTERNAL_SCOPE_ID, HAS_INCOME_EDGE);
-    }
-
-    @Test
-    @Override
-    public void testMarshallSubprocessLevelEventWithIncomeFilledProperties() throws Exception {
-        checkEventMarshalling(FILLED_WITH_INCOME_SUBPROCESS_LEVEL_PROCESS_INSTANCE_SCOPE_ID, HAS_INCOME_EDGE);
-        checkEventMarshalling(FILLED_WITH_INCOME_SUBPROCESS_LEVEL_PROJECT_SCOPE_ID, HAS_INCOME_EDGE);
-        checkEventMarshalling(FILLED_WITH_INCOME_SUBPROCESS_LEVEL_EVENT_EXTERNAL_SCOPE_ID, HAS_INCOME_EDGE);
-    }
-
     @Override
     String getBpmnThrowingIntermediateEventFilePath() {
         return BPMN_THROWING_INTERMEDIATE_EVENT_FILE_PATH;
@@ -328,9 +298,10 @@ public class ThrowingIntermediateSignalEventTest extends ThrowingIntermediateEve
     }
 
     @Override
-    String getFilledTopLevelEventId() {
-        // There are several Filled events, test method is overwritten
-        return null;
+    String[] getFilledTopLevelEventIds() {
+        return new String[]{FILLED_TOP_LEVEL_EVENT_PROCESS_INSTANCE_SCOPE_ID,
+                FILLED_TOP_LEVEL_EVENT_PROJECT_SCOPE_ID,
+                FILLED_TOP_LEVEL_EVENT_EXTERNAL_SCOPE_ID};
     }
 
     @Override
@@ -339,9 +310,10 @@ public class ThrowingIntermediateSignalEventTest extends ThrowingIntermediateEve
     }
 
     @Override
-    String getFilledSubprocessLevelEventId() {
-        // There are several Filled events, test method is overwritten
-        return null;
+    String[] getFilledSubprocessLevelEventIds() {
+        return new String[]{FILLED_SUBPROCESS_LEVEL_PROCESS_INSTANCE_SCOPE_ID,
+                FILLED_SUBPROCESS_LEVEL_PROJECT_SCOPE_ID,
+                FILLED_SUBPROCESS_LEVEL_EVENT_EXTERNAL_SCOPE_ID};
     }
 
     @Override
@@ -350,32 +322,34 @@ public class ThrowingIntermediateSignalEventTest extends ThrowingIntermediateEve
     }
 
     @Override
-    String getFilledTopLevelEventWithIncomeId() {
-        // There are several Filled events, test method is overwritten
-        return null;
+    String[] getFilledTopLevelEventWithEdgesIds() {
+        return new String[]{FILLED_WITH_EDGES_TOP_LEVEL_EVENT_PROCESS_INSTANCE_SCOPE_ID,
+                FILLED_WITH_EDGES_TOP_LEVEL_PROJECT_SCOPE_ID,
+                FILLED_WITH_EDGES_TOP_LEVEL_EVENT_EXTERNAL_SCOPE_ID};
     }
 
     @Override
-    String getEmptyTopLevelEventWithIncomeId() {
-        return EMPTY_WITH_INCOME_TOP_LEVEL_EVENT_ID;
+    String getEmptyTopLevelEventWithEdgesId() {
+        return EMPTY_WITH_EDGES_TOP_LEVEL_EVENT_ID;
     }
 
     @Override
-    String getFilledSubprocessLevelEventWithIncomeId() {
-        // There are several Filled events, test method is overwritten
-        return null;
+    String[] getFilledSubprocessLevelEventWithEdgesIds() {
+        return new String[]{FILLED_WITH_EDGES_SUBPROCESS_LEVEL_PROCESS_INSTANCE_SCOPE_ID,
+                FILLED_WITH_EDGES_SUBPROCESS_LEVEL_PROJECT_SCOPE_ID,
+                FILLED_WITH_EDGES_SUBPROCESS_LEVEL_EVENT_EXTERNAL_SCOPE_ID};
     }
 
     @Override
-    String getEmptySubprocessLevelEventWithIncomeId() {
-        return EMPTY_WITH_INCOME_SUBPROCESS_LEVEL_EVENT_ID;
+    String getEmptySubprocessLevelEventWithEdgesId() {
+        return EMPTY_WITH_EDGES_SUBPROCESS_LEVEL_EVENT_ID;
     }
 
     private void assertSignalEventExecutionSet(ScopedSignalEventExecutionSet executionSet, String signalReference, String signalScope) {
-        assertNotNull(executionSet);
-        assertNotNull(executionSet.getSignalRef());
-        assertNotNull(executionSet.getSignalScope());
-        assertEquals(signalReference, executionSet.getSignalRef().getValue());
-        assertEquals(signalScope, executionSet.getSignalScope().getValue());
+        assertThat(executionSet).isNotNull();
+        assertThat(executionSet.getSignalRef()).isNotNull();
+        assertThat(executionSet.getSignalScope()).isNotNull();
+        assertThat(executionSet.getSignalRef().getValue()).isEqualTo(signalReference);
+        assertThat(executionSet.getSignalScope().getValue()).isEqualTo(signalScope);
     }
 }
