@@ -1,5 +1,5 @@
 /*
- * Copyright 2017 Red Hat, Inc. and/or its affiliates.
+ * Copyright 2019 Red Hat, Inc. and/or its affiliates.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,20 +16,27 @@
 
 package org.kie.workbench.common.stunner.bpmn.client.shape.def;
 
-import java.util.HashMap;
 import java.util.Map;
 import java.util.function.BiConsumer;
 
-import org.kie.workbench.common.stunner.bpmn.client.resources.BPMNSVGGlyphFactory;
+import org.kie.soup.commons.util.Maps;
+import org.kie.workbench.common.stunner.bpmn.client.resources.BPMNGlyphFactory;
 import org.kie.workbench.common.stunner.bpmn.client.resources.BPMNSVGViewFactory;
 import org.kie.workbench.common.stunner.bpmn.client.shape.view.handler.EventCancelActivityViewHandler;
 import org.kie.workbench.common.stunner.bpmn.definition.BaseCatchingIntermediateEvent;
+import org.kie.workbench.common.stunner.bpmn.definition.IntermediateCompensationEvent;
+import org.kie.workbench.common.stunner.bpmn.definition.IntermediateConditionalEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.IntermediateErrorEventCatching;
+import org.kie.workbench.common.stunner.bpmn.definition.IntermediateEscalationEvent;
+import org.kie.workbench.common.stunner.bpmn.definition.IntermediateLinkEventCatching;
 import org.kie.workbench.common.stunner.bpmn.definition.IntermediateMessageEventCatching;
 import org.kie.workbench.common.stunner.bpmn.definition.IntermediateSignalEventCatching;
 import org.kie.workbench.common.stunner.bpmn.definition.IntermediateTimerEvent;
-import org.kie.workbench.common.stunner.core.client.shape.SvgDataUriGlyph;
 import org.kie.workbench.common.stunner.core.client.shape.view.HasTitle;
+import org.kie.workbench.common.stunner.core.client.shape.view.HasTitle.HorizontalAlignment;
+import org.kie.workbench.common.stunner.core.client.shape.view.HasTitle.ReferencePosition;
+import org.kie.workbench.common.stunner.core.client.shape.view.HasTitle.Size.SizeType;
+import org.kie.workbench.common.stunner.core.client.shape.view.HasTitle.VerticalAlignment;
 import org.kie.workbench.common.stunner.core.client.shape.view.handler.CompositeShapeViewHandler;
 import org.kie.workbench.common.stunner.core.client.shape.view.handler.FontHandler;
 import org.kie.workbench.common.stunner.core.client.shape.view.handler.SizeHandler;
@@ -46,27 +53,47 @@ public class CatchingIntermediateEventShapeDef
                          BPMNSVGViewFactory::intermediateTimerEvent)
                     .put(IntermediateSignalEventCatching.class,
                          BPMNSVGViewFactory::intermediateSignalCatchingEvent)
+                    .put(IntermediateLinkEventCatching.class,
+                         BPMNSVGViewFactory::intermediateLinkCatchingEvent)
                     .put(IntermediateErrorEventCatching.class,
                          BPMNSVGViewFactory::intermediateErrorCatchingEvent)
                     .put(IntermediateMessageEventCatching.class,
-                         BPMNSVGViewFactory::intermediateMessageCatchingEvent);
+                         BPMNSVGViewFactory::intermediateMessageCatchingEvent)
+                    .put(IntermediateConditionalEvent.class,
+                         BPMNSVGViewFactory::intermediateConditionalEvent)
+                    .put(IntermediateEscalationEvent.class,
+                         BPMNSVGViewFactory::intermediateEscalationCatchingEvent)
+                    .put(IntermediateCompensationEvent.class,
+                         BPMNSVGViewFactory::intermediateCompensationCatchingEvent);
 
-    public static final Map<Class<? extends BaseCatchingIntermediateEvent>, SvgDataUriGlyph> GLYPHS =
-            new HashMap<Class<? extends BaseCatchingIntermediateEvent>, SvgDataUriGlyph>() {{
-                put(IntermediateTimerEvent.class,
-                    BPMNSVGGlyphFactory.INTERMEDIATE_TIMER_EVENT_GLYPH);
-                put(IntermediateSignalEventCatching.class,
-                    BPMNSVGGlyphFactory.INTERMEDIATE_SIGNAL_EVENT_GLYPH);
-                put(IntermediateErrorEventCatching.class,
-                    BPMNSVGGlyphFactory.INTERMEDIATE_ERROR_EVENT_GLYPH);
-                put(IntermediateMessageEventCatching.class,
-                    BPMNSVGGlyphFactory.INTERMEDIATE_MESSAGE_EVENT_GLYPH);
-            }};
+    public static final Map<Class<? extends BaseCatchingIntermediateEvent>, Glyph> GLYPHS =
+            new Maps.Builder<Class<? extends BaseCatchingIntermediateEvent>, Glyph>()
+                    .put(IntermediateTimerEvent.class,
+                         BPMNGlyphFactory.EVENT_INTERMEDIATE_TIMER)
+                    .put(IntermediateSignalEventCatching.class,
+                         BPMNGlyphFactory.EVENT_INTERMEDIATE_SIGNAL)
+                    .put(IntermediateLinkEventCatching.class,
+                         BPMNGlyphFactory.EVENT_INTERMEDIATE_LINK)
+                    .put(IntermediateErrorEventCatching.class,
+                         BPMNGlyphFactory.EVENT_INTERMEDIATE_ERROR)
+                    .put(IntermediateMessageEventCatching.class,
+                         BPMNGlyphFactory.EVENT_INTERMEDIATE_MESSAGE)
+                    .put(IntermediateConditionalEvent.class,
+                         BPMNGlyphFactory.EVENT_INTERMEDIATE_CONDITIONAL)
+                    .put(IntermediateEscalationEvent.class,
+                         BPMNGlyphFactory.EVENT_INTERMEDIATE_ESCALATION)
+                    .put(IntermediateCompensationEvent.class,
+                         BPMNGlyphFactory.EVENT_INTERMEDIATE_COMPENSATION)
+                    .build();
 
     @Override
     public FontHandler<BaseCatchingIntermediateEvent, SVGShapeView> newFontHandler() {
         return newFontHandlerBuilder()
-                .positon(event -> HasTitle.Position.BOTTOM)
+                .verticalAlignment(bean -> VerticalAlignment.BOTTOM)
+                .horizontalAlignment(bean -> HorizontalAlignment.CENTER)
+                .referencePosition(bean -> ReferencePosition.OUTSIDE)
+                .textSizeConstraints(bean -> new HasTitle.Size(400, 100, SizeType.PERCENTAGE))
+                .margin(VerticalAlignment.BOTTOM, 5d)
                 .build();
     }
 
