@@ -19,7 +19,6 @@ package org.kie.workbench.common.stunner.bpmn.client.dataproviders;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.Map;
-import java.util.Spliterators;
 import java.util.function.Function;
 
 import org.junit.Before;
@@ -29,15 +28,15 @@ import org.kie.workbench.common.forms.dynamic.model.config.SelectorData;
 import org.kie.workbench.common.forms.dynamic.model.config.SelectorDataProvider;
 import org.kie.workbench.common.forms.dynamic.service.shared.FormRenderingContext;
 import org.kie.workbench.common.stunner.core.client.api.SessionManager;
-import org.kie.workbench.common.stunner.core.client.canvas.CanvasHandler;
-import org.kie.workbench.common.stunner.core.client.session.ClientFullSession;
+import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler;
+import org.kie.workbench.common.stunner.core.client.session.impl.EditorSession;
 import org.kie.workbench.common.stunner.core.diagram.Diagram;
 import org.kie.workbench.common.stunner.core.graph.Element;
 import org.kie.workbench.common.stunner.core.graph.Graph;
 import org.kie.workbench.common.stunner.core.graph.Node;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
 import org.mockito.Mock;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertTrue;
@@ -51,10 +50,10 @@ public abstract class AbstractProcessFilteredNodeProviderBaseTest {
     protected SessionManager sessionManager;
 
     @Mock
-    protected ClientFullSession session;
+    protected EditorSession session;
 
     @Mock
-    protected CanvasHandler canvasHandler;
+    protected AbstractCanvasHandler canvasHandler;
 
     @Mock
     protected Diagram diagram;
@@ -84,8 +83,6 @@ public abstract class AbstractProcessFilteredNodeProviderBaseTest {
     public void testGetSelectorDataWithNoValues() {
         @SuppressWarnings("unchecked")
         Iterable<Element> nodes = mock(Iterable.class);
-        when(graph.nodes()).thenReturn(nodes);
-        when(nodes.spliterator()).thenReturn(Spliterators.emptySpliterator());
         SelectorData selectorData = provider.getSelectorData(renderingContext);
         Map values = selectorData.getValues();
         assertTrue(values.isEmpty());
