@@ -38,6 +38,7 @@ import org.kie.workbench.common.stunner.bpmn.client.forms.util.StringUtils;
 import org.kie.workbench.common.stunner.bpmn.definition.BPMNDefinition;
 import org.kie.workbench.common.stunner.bpmn.definition.BPMNDiagramImpl;
 import org.kie.workbench.common.stunner.bpmn.definition.BusinessRuleTask;
+import org.kie.workbench.common.stunner.bpmn.definition.DataObject;
 import org.kie.workbench.common.stunner.bpmn.definition.EndNoneEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.EndTerminateEvent;
 import org.kie.workbench.common.stunner.bpmn.definition.SequenceFlow;
@@ -70,7 +71,7 @@ import org.powermock.modules.junit4.PowerMockRunner;
 import org.uberfire.commons.data.Pair;
 
 import static org.junit.Assert.assertEquals;
-import static org.mockito.Matchers.anyObject;
+import static org.mockito.ArgumentMatchers.anyObject;
 import static org.mockito.Mockito.any;
 import static org.mockito.Mockito.anyBoolean;
 import static org.mockito.Mockito.anyString;
@@ -95,7 +96,7 @@ public class AssignmentsEditorWidgetTest extends AssignmentBaseTest {
     public static final String ASSIGNMENTS_SINGLE_INPUT = "[din]employee->input1";
     public static final String ASSIGNMENTS_SINGLE_OUTPUT = "[dout]output1->employee";
     public static final String ASSIGNMENTS_MULTIPLE = "[din]employee->input1,[din]input2=ab%7Ccd%7Cef,[din]input3=yes,[din]input4=%22Hello%22+then+%22Goodbye%22,[dout]output1->employee,[dout]output2->reason";
-    public static final List<String> DATATYPES = new ArrayList<String>(Arrays.asList("myorg.myproject1.Cardboard",
+    public static final List<String> DATATYPES = new ArrayList<>(Arrays.asList("myorg.myproject1.Cardboard",
                                                                                      "yourorg.materials.Paper",
                                                                                      "org.documents.Articles"));
     public static final String FORMATTED_DATATYPES = "Articles [org.documents]:org.documents.Articles,Cardboard [myorg.myproject1]:myorg.myproject1.Cardboard,Paper [yourorg.materials]:yourorg.materials.Paper";
@@ -191,15 +192,15 @@ public class AssignmentsEditorWidgetTest extends AssignmentBaseTest {
         widget.activityDataIOEditor = activityDataIOEditor;
         widget.canvasSessionManager = canvasSessionManager;
         activityDataIOEditor.view = activityDataIOEditorView;
-        doCallRealMethod().when(widget).getVariableCountsString(anyString(),
-                                                                anyString(),
-                                                                anyString(),
-                                                                anyString(),
-                                                                anyString(),
-                                                                anyString(),
-                                                                anyString());
+        doCallRealMethod().when(widget).getVariableCountsString(any(),
+                                                                any(),
+                                                                any(),
+                                                                any(),
+                                                                any(),
+                                                                any(),
+                                                                any());
         doCallRealMethod().when(widget).showAssignmentsDialog();
-        doCallRealMethod().when(widget).showDataIOEditor(anyString());
+        doCallRealMethod().when(widget).showDataIOEditor(any());
         doCallRealMethod().when(widget).setBPMNModel(any(BPMNDefinition.class));
         doCallRealMethod().when(widget).formatDataTypes(any(List.class));
         doCallRealMethod().when(widget).getTaskName();
@@ -232,7 +233,7 @@ public class AssignmentsEditorWidgetTest extends AssignmentBaseTest {
         doCallRealMethod().when(endNoneEvent).isSingleInputVar();
         doCallRealMethod().when(endNoneEvent).hasOutputVars();
         doCallRealMethod().when(endNoneEvent).isSingleOutputVar();
-        doCallRealMethod().when(activityDataIOEditor).configureDialog(anyString(),
+        doCallRealMethod().when(activityDataIOEditor).configureDialog(any(),
                                                                       anyBoolean(),
                                                                       anyBoolean(),
                                                                       anyBoolean(),
@@ -481,6 +482,14 @@ public class AssignmentsEditorWidgetTest extends AssignmentBaseTest {
                times(1)).setReadOnly(false);
     }
 
+    @Test
+    public void testDataObjectsNewLine() {
+        DataObject dataObject = new DataObject();
+        dataObject.getName().setValue("Data\nObject");
+        String doNameFilter = widget.dataObjectToProcessVariableFormat(dataObject);
+        assertEquals(doNameFilter, "DataObject:Object");
+     }
+
     @Test
     public void testAssignmentsForNormalTaskWithInputOutput() {
         setUpProcessVariables();
