@@ -65,9 +65,9 @@ public abstract class EventPropertyWriter extends PropertyWriter {
     public abstract void setAssignmentsInfo(AssignmentsInfo assignmentsInfo);
 
     public void addMessage(MessageRef messageRef) {
-
-        // since events only have one parameter, look for the only one
-        if (messageRef.getStructure().isEmpty() && this.getItemDefinitions().size() == 1) {
+        if (this.getItemDefinitions().isEmpty()) {
+            messageRef.setStructure("");
+        } else {
             messageRef.setStructure(this.getItemDefinitions().get(0).getStructureRef());
         }
 
